<?php
/**
 * Lists out all the options from the Blog Features Section of the theme options
 * This file is included in functions.php
 *
 * @package Suffusion
 * @subpackage Admin
 */

global $shortname, $theme_name, $font_faces, $all_page_ids, $all_category_ids, $sidebar_tabs, $social_networks, $suffusion_comment_label_name, $suffusion_comment_label_req, $suffusion_comment_label_email, $suffusion_comment_label_uri, $suffusion_comment_label_your_comment;
$blog_features_options = array(
	array("name" => "Blog Features",
		"type" => "sub-section-2",
		"category" => "blog-features",
		"parent" => "root"
	),

	array("name" => "Main Navigation Bar Setup",
		"type" => "sub-section-3",
		"category" => "nav-setup",
		"parent" => "blog-features"
	),

	array("name" => "Main Navigation Bar Look and Feel",
		"category" => "nav-lf",
		"parent" => "nav-setup",
		"type" => "sub-section-4",),

	array("name" => "Show / Hide Main Navigation Bar",
		"id" => $shortname . "_nav_contents",
		"parent" => "nav-setup",
		"grouping" => "nav-lf",
		"type" => "radio",
		"options" => array("pages" => "Drop-down menus (Default)", "hide" => "Hidden"),
		"std" => "pages"),

	array("name" => "Main Navigation Bar Style",
		"desc" => "This will only be effective if your Header is outside the main wrapper (see Visual Effects &rarr; Header Customization):",
		"id" => $shortname . "_nav_bar_style",
		"parent" => "nav-setup",
		"grouping" => "nav-lf",
		"type" => "radio",
		"options" => array("full-full" => "Navigation bar is as wide as your browser window and contents of the bar begin from the left or right",
			"full-align" => "Navigation bar is as wide as your browser window and contents of the bar are aligned with your main page",
			"align" => "Navigation bar and its contents are aligned with your main page", "theme" => "Theme Default"),
		"std" => "theme"),

	array("name" => "Menu Item Style",
		"id" => $shortname . "_nav_item_type",
		"parent" => "nav-setup",
		"grouping" => "nav-lf",
		"type" => "radio",
		"options" => array("tab" => "Show menu items as individual tabs", "continuous" => "Show menu items as a continuous list", "theme" => "Theme Default"),
		"std" => "theme"),

	array("name" => "Drop-down menu delay",
		"desc" => "You can set a delay for the drop-down menu in the navigation bar.",
		"id" => $shortname . "_nav_delay",
		"parent" => "nav-setup",
		"grouping" => "nav-lf",
		"type" => "text",
		"hint" => "Leave blank for no delay",
		"std" => "500"),

	array("name" => "Fade effect for drop-down menu",
		"desc" => "There is a fade-in effect for the drop-down menu enabled by default. You can disable it",
		"id" => $shortname . "_nav_effect",
		"parent" => "nav-setup",
		"grouping" => "nav-lf",
		"type" => "radio",
		"options" => array("none" => "No effects", "fade" => "Fade in the page"),
		"std" => "fade"),

	array("name" => "Show \"Home\" page?",
		"desc" => "You can show a link to your blog's home page. This could either be an icon or a text link. This setting is ignored if you are hiding your navigation bar.",
		"id" => $shortname . "_show_home",
		"parent" => "nav-setup",
		"grouping" => "nav-lf",
		"type" => "radio",
		"options" => array("none" => "Don't show a home link (default)", "text" => "Show a text link", "icon" => "Show an icon"),
		"std" => "none"),

	array("name" => "\"Home\" page text",
		"desc" => "If you have opted to show a text link above, you can set the text to show. The default is \"Home\".
				This setting is ignored if you are hiding your navigation bar or if you have chosen to not show a home link or to show a home icon.",
		"id" => $shortname . "_home_text",
		"parent" => "nav-setup",
		"grouping" => "nav-lf",
		"type" => "text",
		"std" => "Home"),

	array("name" => "Order of entities in navigation bar",
		"desc" => "You can define the order in which Pages, Categories and Links (Bookmarks) appear in the navigation bar: ",
		"id" => $shortname . "_nav_entity_order",
		"parent" => "nav-setup",
		"grouping" => "nav-lf",
		"type" => "sortable-list",
		"std" => suffusion_entity_prepositions('nav')),

	array("name" => "Text Transformation for Navigation Bar",
		"id" => $shortname . "_nav_text_transform",
		"parent" => "nav-setup",
		"grouping" => "nav-lf",
		"type" => "radio",
		"options" => array("uppercase" => "ALL UPPERCASE", "lowercase" => "all lowercase",
			"capitalize" => "Capitalize First Letter Of Each Word (default)", "none" => "No transformation"),
		"std" => "capitalize"),

	array("name" => "Pages in Navigation Bar",
		"desc" => "Control the display of pages in the navigation bar",
		"category" => "nav-pages",
		"parent" => "nav-setup",
		"type" => "sub-section-4",),

	array("name" => "Page listing style in Navigation Bar",
		"desc" => "You can choose how to show pages in your navigation bar. By default a single tab for pages is shown in the navigation bar.",
		"id" => $shortname . "_nav_pages_style",
		"parent" => "nav-setup",
		"grouping" => "nav-pages",
		"type" => "radio",
		"options" => array("flattened" => "<div class='picture'><img src='" . get_template_directory_uri() . "/admin/images/nav-page-flat.jpg' alt='Flattened'/><p>Show the top level pages in the navigation bar and their sub-pages in drop-downs</p></div>",
			"rolled-up" => "<div class='picture'><img src='" . get_template_directory_uri() . "/admin/images/nav-page-roll-up.jpg' alt='Flattened'/><p>Show a single tab called \"Pages\" (or whatever you want to call it) and build a drop-down under it (default)</p></div>"),
		"std" => "rolled-up"),

	array("name" => "\"Pages\" tab title",
		"desc" => "In the above option if you have chosen to show a single tab for pages and build a drop-down under it, you can set the title for that tab.
				This setting is ignored if you have chosen to display top level pages in the navigation bar.",
		"id" => $shortname . "_nav_page_tab_title",
		"parent" => "nav-setup",
		"grouping" => "nav-pages",
		"type" => "text",
		"std" => "Pages"),

	array("name" => "\"Pages\" tab link",
		"desc" => "If you have a specific page that you want to go to upon clicking the Pages tab, set the full URL here.
				This setting is ignored if you have chosen to display top level pages in the navigation bar.",
		"id" => $shortname . "_nav_page_tab_link",
		"parent" => "nav-setup",
		"grouping" => "nav-pages",
		"type" => "text",
		"hint" => "Enter the full URL, including http://",
		"std" => ""),

	array("name" => "Pages in Navigation Bar - All or Selected",
		"desc" => "Choose which pages you want to display in your navigation bar.",
		"id" => $shortname . "_nav_pages_all_sel",
		"parent" => "nav-setup",
		"grouping" => "nav-pages",
		"type" => "radio",
		"options" => array("all" => "Include all, ignoring next option", "selected" => "Include selections from the next option",
			"exclude-all" => "Exclude all, ignoring next option", "exclude-selected" => "Exclude selections from the next option"),
		"std" => "all"),

	array("name" => "Select pages to include/exclude in Navigation Bar",
		"desc" => "The selections here will be used with the previous option.",
		"id" => $shortname . "_nav_pages",
		"parent" => "nav-setup",
		"grouping" => "nav-pages",
		"export" => "ne",
		"type" => "multi-select",
		"options" => suf_get_formatted_page_array($shortname . "_nav_pages"),
		"std" => $all_page_ids),

	array("name" => "Categories in Navigation Bar",
		"desc" => "Control the display of categories in the navigation bar",
		"category" => "nav-cats",
		"parent" => "nav-setup",
		"type" => "sub-section-4",),

	array("name" => "Category listing style in Navigation Bar",
		"desc" => "You can choose how to show categories in your navigation bar. By default a single tab for categories is shown in the navigation bar.",
		"id" => $shortname . "_nav_cat_style",
		"parent" => "nav-setup",
		"grouping" => "nav-cats",
		"type" => "radio",
		"options" => array("flattened" => "<div class='picture'><img src='" . get_template_directory_uri() . "/admin/images/nav-cat-flat.jpg' alt='Flattened'/><p>Show the top level categories in the navigation bar and their sub-pages in drop-downs</p></div>",
			"rolled-up" => "<div class='picture'><img src='" . get_template_directory_uri() . "/admin/images/nav-cat-roll-up.jpg' alt='Flattened'/><p>Show a single tab called \"Categories\" (or whatever you want to call it) and build a drop-down under it (default)</p></div>"),
		"std" => "rolled-up"),

	array("name" => "\"Categories\" tab title",
		"desc" => "In the above option if you have chosen to show a single tab for categories and build a drop-down under it, you can set the title for that tab.
				This setting is ignored if you have chosen to display top level categories in the navigation bar.",
		"id" => $shortname . "_nav_cat_tab_title",
		"parent" => "nav-setup",
		"grouping" => "nav-cats",
		"type" => "text",
		"std" => "Categories"),

	array("name" => "\"Categories\" tab link",
		"desc" => "If you have a specific page that you want to go to upon clicking the Categories tab, set the full URL here.
				This setting is ignored if you have chosen to display top level categories in the navigation bar.",
		"id" => $shortname . "_nav_cat_tab_link",
		"parent" => "nav-setup",
		"grouping" => "nav-cats",
		"type" => "text",
		"hint" => "Enter the full URL, including http://",
		"std" => ""),

	array("name" => "Categories in Navigation Bar - All or Selected",
		"desc" => "Choose which categories you want to display in your navigation bar.",
		"id" => $shortname . "_nav_cats_all_sel",
		"parent" => "nav-setup",
		"grouping" => "nav-cats",
		"type" => "radio",
		"options" => array("all" => "Include all, ignoring next option", "selected" => "Include selections from the next option",
			"exclude-all" => "Exclude all, ignoring next option", "exclude-selected" => "Exclude selections from the next option"),
		"std" => "all"),

	array("name" => "Select categories to show in Navigation Bar",
		"desc" => "If you have too many categories on your blog you might want to exclude some so that the navigation bar doesn't get ugly. Note that if your navigation bar is hidden, this setting is ignored. Also if you select a category whose parent is not selected, the child will NOT be displayed.
				The exclusion is hierarchical, so if you exclude a parent category but include its child, neither the parent nor the child will show up in the dropdown. All categories are excluded by default. ",
		"id" => $shortname . "_nav_cats",
		"parent" => "nav-setup",
		"grouping" => "nav-cats",
		"export" => "ne",
		"type" => "multi-select",
		"options" => suf_get_formatted_category_array($shortname . "_nav_cats"),
		'std' => $all_category_ids),

	array("name" => "Links in Navigation Bar",
		"desc" => "Control the display of links in the navigation bar",
		"category" => "nav-links",
		"parent" => "nav-setup",
		"type" => "sub-section-4",),

	array("name" => "WordPress Link listing style in Navigation Bar",
		"desc" => "You can choose how to show links in your navigation bar. By default a single tab for links is shown in the navigation bar.",
		"id" => $shortname . "_nav_links_style",
		"parent" => "nav-setup",
		"grouping" => "nav-links",
		"type" => "radio",
		"options" => array("flattened" => "<div class='picture'><img src='" . get_template_directory_uri() . "/admin/images/nav-link-flat.jpg' alt='Flattened'/><p>Show the links in the navigation bar</p></div>",
			"rolled-up" => "<div class='picture'><img src='" . get_template_directory_uri() . "/admin/images/nav-link-roll-up.jpg' alt='Flattened'/><p>Show a single tab called \"Links\" (or whatever you want to call it) and build a drop-down under it</p></div>"),
		"std" => "rolled-up"),

	array("name" => "\"Links\" tab title",
		"desc" => "In the above option if you have chosen to show a single tab for WordPress links and build a drop-down under it, you can set the title for that tab.
				This setting is ignored if you have chosen to display individual links in the navigation bar.",
		"id" => $shortname . "_nav_links_tab_title",
		"parent" => "nav-setup",
		"grouping" => "nav-links",
		"type" => "text",
		"std" => "Links"),

	array("name" => "\"Links\" tab link",
		"desc" => "If you have a specific page that you want to go to upon clicking the Links tab, set the full URL here.
				This setting is ignored if you have chosen to display top level links in the navigation bar.",
		"id" => $shortname . "_nav_links_tab_link",
		"parent" => "nav-setup",
		"grouping" => "nav-links",
		"type" => "text",
		"hint" => "Enter the full URL, including http://",
		"std" => ""),

	array("name" => "Links in Navigation Bar - All or Selected",
		"desc" => "Choose which links you want to display",
		"id" => $shortname . "_nav_links_all_sel",
		"parent" => "nav-setup",
		"grouping" => "nav-links",
		"type" => "radio",
		"options" => array("all" => "Include all, ignoring next option", "selected" => "Include selections from the next option",
			"exclude-all" => "Exclude all, ignoring next option", "exclude-selected" => "Exclude selections from the next option"),
		"std" => "selected"),

	array("name" => "Select links to show in Navigation Bar",
		"desc" => "If you have too many links on your blog you might want to exclude some so that the navigation bar doesn't get ugly. Note that if your navigation bar is hidden, this setting is ignored.
				All links are excluded by default. ",
		"id" => $shortname . "_nav_links",
		"parent" => "nav-setup",
		"grouping" => "nav-links",
		"export" => "ne",
		"type" => "multi-select",
		"options" => suf_get_formatted_link_array($shortname . "_nav_links")),

	array("name" => "WP 3.0 Navigation Menus",
		"desc" => "Control the display of inbuilt navigation menus (WP 3.0 and higher)",
		"category" => "nav-3menu",
		"parent" => "nav-setup",
		"type" => "sub-section-4",),

	array("name" => "WP 3.0 Navigation Menus - All or Selected",
		"desc" => "You can decide if you want to show all menus or selected menus in the navigation bar.
			If you choose 'All' your settings in the next option will be ignored. Also note that if you have added a menu to the navigation bar through the WP 3.0 menu administration page, it will show up even if excluded here.
			Note that this option is different from choosing 'Select All' in the next option, because this guarantees that always all are displayed, while the next option only ensures that all selections at the time of setup are displayed",
		"id" => $shortname . "_nav_menus_all_sel",
		"parent" => "nav-setup",
		"grouping" => "nav-3menu",
		"type" => "radio",
		"options" => array("all" => "All, ignoring next option", "selected" => "Selections from the next option"),
		"std" => "selected"),

	array("name" => "Select Menus to show",
		"desc" => "If you have too many menus on your blog you might want to exclude some so that the navigation bar doesn't get ugly.
			All menus are included by default. ",
		"id" => $shortname . "_nav_menus",
		"parent" => "nav-setup",
		"grouping" => "nav-3menu",
		"export" => "ne",
		"type" => "multi-select",
		"options" => suf_get_formatted_wp_menu_array($shortname . "_nav_menus")),

	array("name" => "Navigation Breadcrumb",
		"desc" => "Control the breadcrumb display. Note that this option will control breadcrumbs for <i>both, the top navigation bar and the main navigation bar</i>.",
		"category" => "nav-bc",
		"parent" => "nav-setup",
		"type" => "sub-section-4",),

	array("name" => "Excluded pages in breadcrumb",
		"desc" => "Pages excluded in the drop down menu are not shown in the breadcrumb. You might want to change this setting if you want all pages to be available for navigation:",
		"id" => $shortname . "_nav_exclude_in_breadcrumb",
		"parent" => "nav-setup",
		"grouping" => "nav-bc",
		"type" => "radio",
		"options" => array("hide" => "Hide excluded pages", "show" => "Show excluded pages"),
		"std" => "hide"),

	array("name" => "Breadcrumb Navigation for Pages",
		"desc" => "For every page that you visit you see all siblings of the page, its parent and all siblings of the parent below the navigation bar.
				This is okay if you have a small number of pages at each level, but cumbersome if you have many siblings (it messes up the display). You can change this setting:",
		"id" => $shortname . "_nav_breadcrumb",
		"parent" => "nav-setup",
		"grouping" => "nav-bc",
		"type" => "radio",
		"options" => array("all" => "Show all siblings, and all siblings of parent (default)",
			"breadcrumb" => "Don't show siblings, but show entire path to the page (traditional \"breadcrumb\" display)",
			"none" => "Hide the breadcrumb view altogether"),
		"std" => "breadcrumb"),

	array("name" => "Breadcrumb Separator",
		"desc" => "This is the symbol that appears as a separator between levels in your breadcrumb.
				If you have selected the \"breadcrumb\" display above then the setting you make here takes effect. Otherwise this is ignored:",
		"id" => $shortname . "_breadcrumb_separator",
		"parent" => "nav-setup",
		"grouping" => "nav-bc",
		"type" => "text",
//			"hint" => "Use &amp;bull; for &bull;, &amp;gt; for &gt; and &amp;raquo; for &raquo;",
		"std" => "&raquo;"),

	array("name" => "\"Title\" attribute upon hovering over navigation bar",
		"desc" => "If you set this to show the title, when you hover over the menu, a little box with the title of the link will show up.
			This applies to both navigation bars. Also, the WP 3.0 menus are not impacted by this setting:",
		"id" => $shortname . "_nav_strip_a_title",
		"parent" => "nav-setup",
		"type" => "radio",
		"options" => array("show" => "Show title attribute", "hide" => "Hide title attribute"),
		"std" => "hide"),

	array("name" => "Top Navigation Bar Setup",
		"type" => "sub-section-3",
		"category" => "navt-setup",
		"parent" => "blog-features"
	),

	array("name" => "Top Navigation Bar Look and Feel",
		"desc" => "Adjust the general look and feel options of the Top Navigation Bar",
		"category" => "navt-lf",
		"parent" => "navt-setup",
		"type" => "sub-section-4",),

	array("name" => "Set up the Top Navigation Bar",
		"desc" => "You can define what you want to show in your top navigation bar. The navigation bar contains two widget areas, 'Top Bar Left Widgets' and 'Top Bar Right Widgets' and a drop down menu.
				If you prefer having pages, categories and links listed in the sidebar, select \"Hidden\".",
		"id" => $shortname . "_navt_contents",
		"parent" => "navt-setup",
		"grouping" => "navt-lf",
		"type" => "radio",
		"options" => array("pages" => "Drop-down menus and widget areas", "hide" => "Hidden (Default)"),
		"std" => "hide"),

	array("name" => "Top Navigation Bar Style",
		"desc" => "You can choose different navigation bar styles - full width or page width:",
		"id" => $shortname . "_navt_bar_style",
		"parent" => "navt-setup",
		"grouping" => "navt-lf",
		"type" => "radio",
		"options" => array("full-full" => "Navigation bar is as wide as your browser window and contents of the bar begin from the left or right",
			"full-align" => "Navigation bar is as wide as your browser window and contents of the bar are aligned with your main page",
			"align" => "Navigation bar and its contents are aligned with your main page", "theme" => "Theme Default"),
		"std" => "theme"),

	array("name" => "Drop-down menu position",
		"desc" => "Where in the navigation bar do you want your drop-down menu?",
		"id" => $shortname . "_navt_dd_pos",
		"parent" => "navt-setup",
		"grouping" => "navt-lf",
		"type" => "radio",
		"concept" => "halign",
		"options" => array("left" => "Left", "right" => "Right"),
		"std" => "left"),

	array("name" => "Menu Item Style",
		"desc" => "Control how your menu items look",
		"id" => $shortname . "_navt_item_type",
		"parent" => "navt-setup",
		"grouping" => "navt-lf",
		"type" => "radio",
		"options" => array("tab" => "Show menu items as individual tabs", "continuous" => "Show menu items as a continuous list", "theme" => "Theme Default"),
		"std" => "theme"),

	array("name" => "Drop-down menu delay",
		"desc" => "You can set a delay for the drop-down menu in the navigation bar.",
		"id" => $shortname . "_navt_delay",
		"parent" => "navt-setup",
		"grouping" => "navt-lf",
		"type" => "text",
		"hint" => "Leave blank for no delay",
		"std" => "500"),

	array("name" => "Fade effect for drop-down menu",
		"desc" => "There is a fade-in effect for the drop-down menu enabled by default. You can disable it",
		"id" => $shortname . "_navt_effect",
		"parent" => "navt-setup",
		"grouping" => "navt-lf",
		"type" => "radio",
		"options" => array("none" => "No effects", "fade" => "Fade in the page"),
		"std" => "fade"),

	array("name" => "Show \"Home\" page?",
		"desc" => "You can show a link to your blog's home page. This could either be an icon or a text link. This setting is ignored if you are hiding your navigation bar.",
		"id" => $shortname . "_navt_show_home",
		"parent" => "navt-setup",
		"grouping" => "navt-lf",
		"type" => "radio",
		"options" => array("none" => "Don't show a home link (default)", "text" => "Show a text link", "icon" => "Show an icon"),
		"std" => "none"),

	array("name" => "\"Home\" page text",
		"desc" => "If you have opted to show a text link above, you can set the text to show. The default is \"Home\".
				This setting is ignored if you are hiding your navigation bar or if you have chosen to not show a home link or to show a home icon.",
		"id" => $shortname . "_navt_home_text",
		"parent" => "navt-setup",
		"grouping" => "navt-lf",
		"type" => "text",
		"std" => "Home"),

	array("name" => "Order of entities in top navigation bar",
		"desc" => "You can define the order in which Pages, Categories and Links (Bookmarks) appear in the navigation bar: ",
		"id" => $shortname . "_navt_entity_order",
		"parent" => "navt-setup",
		"grouping" => "navt-lf",
		"type" => "sortable-list",
		"std" => suffusion_entity_prepositions('nav')),

	array("name" => "Text Transformation for Top Navigation Bar",
		"desc" => "By default all your page names are displayed with the first letter of each word capitalized in the navigation bar (except in IE 6, where it is unstyled). You can change this setting:",
		"id" => $shortname . "_navt_text_transform",
		"parent" => "navt-setup",
		"grouping" => "navt-lf",
		"type" => "radio",
		"options" => array("uppercase" => "ALL UPPERCASE", "lowercase" => "all lowercase",
			"capitalize" => "Capitalize First Letter Of Each Word (default)", "none" => "No transformation"),
		"std" => "capitalize"),

	array("name" => "Pages in Navigation Bar",
		"desc" => "Control the display of pages in the navigation bar",
		"category" => "navt-pages",
		"parent" => "navt-setup",
		"type" => "sub-section-4",),

	array("name" => "Page listing style in top Navigation Bar",
		"desc" => "You can choose how to show pages in your navigation bar. By default a single tab for pages is shown in the navigation bar.",
		"id" => $shortname . "_navt_pages_style",
		"parent" => "navt-setup",
		"grouping" => "navt-pages",
		"type" => "radio",
		"options" => array("flattened" => "<div class='picture'><img src='" . get_template_directory_uri() . "/admin/images/nav-page-flat.jpg' alt='Flattened'/><p>Show the top level pages in the navigation bar and their sub-pages in drop-downs</p></div>",
			"rolled-up" => "<div class='picture'><img src='" . get_template_directory_uri() . "/admin/images/nav-page-roll-up.jpg' alt='Flattened'/><p>Show a single tab called \"Pages\" (or whatever you want to call it) and build a drop-down under it (default)</p></div>"),
		"std" => "rolled-up"),

	array("name" => "\"Pages\" tab title",
		"desc" => "In the above option if you have chosen to show a single tab for pages and build a drop-down under it, you can set the title for that tab.
				This setting is ignored if you have chosen to display top level pages in the navigation bar.",
		"id" => $shortname . "_navt_page_tab_title",
		"parent" => "navt-setup",
		"grouping" => "navt-pages",
		"type" => "text",
		"std" => "Pages"),

	array("name" => "\"Pages\" tab link",
		"desc" => "If you have a specific page that you want to go to upon clicking the Pages tab, set the full URL here.
				This setting is ignored if you have chosen to display top level pages in the navigation bar.",
		"id" => $shortname . "_navt_page_tab_link",
		"parent" => "navt-setup",
		"grouping" => "navt-pages",
		"type" => "text",
		"hint" => "Enter the full URL, including http://",
		"std" => ""),

	array("name" => "Pages in Navigation Bar - All or Selected",
		"desc" => "Choose which pages you want to display in your navigation bar.",
		"id" => $shortname . "_navt_pages_all_sel",
		"parent" => "navt-setup",
		"grouping" => "navt-pages",
		"type" => "radio",
		"options" => array("all" => "Include all, ignoring next option", "selected" => "Include selections from the next option",
			"exclude-all" => "Exclude all, ignoring next option", "exclude-selected" => "Exclude selections from the next option"),
		"std" => "selected"),

	array("name" => "Select pages to show in Navigation Bar",
		"desc" => "If you have too many pages on your blog you might want to exclude some so that the navigation bar doesn't get ugly. Note that if your navigation bar is hidden, this setting is ignored. Also if you select a page whose parent is not selected, the child will NOT be displayed. All pages are excluded by default",
		"id" => $shortname . "_navt_pages",
		"parent" => "navt-setup",
		"grouping" => "navt-pages",
		"export" => "ne",
		"type" => "multi-select",
		"options" => suf_get_formatted_page_array($shortname . "_navt_pages"),
		"std" => ""),

	array("name" => "Categories in Navigation Bar",
		"desc" => "Control the display of categories in the navigation bar",
		"category" => "navt-cats",
		"parent" => "navt-setup",
		"type" => "sub-section-4",),

	array("name" => "Category listing style in Navigation Bar",
		"desc" => "You can choose how to show categories in your navigation bar. By default a single tab for categories is shown in the navigation bar.",
		"id" => $shortname . "_navt_cat_style",
		"parent" => "navt-setup",
		"grouping" => "navt-cats",
		"type" => "radio",
		"options" => array("flattened" => "<div class='picture'><img src='" . get_template_directory_uri() . "/admin/images/nav-cat-flat.jpg' alt='Flattened'/><p>Show the top level categories in the navigation bar and their sub-pages in drop-downs</p></div>",
			"rolled-up" => "<div class='picture'><img src='" . get_template_directory_uri() . "/admin/images/nav-cat-roll-up.jpg' alt='Flattened'/><p>Show a single tab called \"Categories\" (or whatever you want to call it) and build a drop-down under it (default)</p></div>"),
		"std" => "rolled-up"),

	array("name" => "\"Categories\" tab title",
		"desc" => "In the above option if you have chosen to show a single tab for categories and build a drop-down under it, you can set the title for that tab.
				This setting is ignored if you have chosen to display top level categories in the navigation bar.",
		"id" => $shortname . "_navt_cat_tab_title",
		"parent" => "navt-setup",
		"grouping" => "navt-cats",
		"type" => "text",
		"std" => "Categories"),

	array("name" => "\"Categories\" tab link",
		"desc" => "If you have a specific page that you want to go to upon clicking the Categories tab, set the full URL here.
				This setting is ignored if you have chosen to display top level categories in the navigation bar.",
		"id" => $shortname . "_navt_cat_tab_link",
		"parent" => "navt-setup",
		"grouping" => "navt-cats",
		"type" => "text",
		"hint" => "Enter the full URL, including http://",
		"std" => ""),

	array("name" => "Categories in Navigation Bar - All or Selected",
		"desc" => "Choose which categories you want to display in your navigation bar.",
		"id" => $shortname . "_navt_cats_all_sel",
		"parent" => "navt-setup",
		"grouping" => "navt-cats",
		"type" => "radio",
		"options" => array("all" => "Include all, ignoring next option", "selected" => "Include selections from the next option",
			"exclude-all" => "Exclude all, ignoring next option", "exclude-selected" => "Exclude selections from the next option"),
		"std" => "selected"),

	array("name" => "Select categories to show in Navigation Bar",
		"desc" => "If you have too many categories on your blog you might want to exclude some so that the navigation bar doesn't get ugly. Note that if your navigation bar is hidden, this setting is ignored. Also if you select a category whose parent is not selected, the child will NOT be displayed.
				The exclusion is hierarchical, so if you exclude a parent category but include its child, neither the parent nor the child will show up in the dropdown. All categories are excluded by default. ",
		"id" => $shortname . "_navt_cats",
		"parent" => "navt-setup",
		"grouping" => "navt-cats",
		"export" => "ne",
		"type" => "multi-select",
		"options" => suf_get_formatted_category_array($shortname . "_navt_cats"),
		'std' => ""),

	array("name" => "Links in Navigation Bar",
		"desc" => "Control the display of links in the navigation bar",
		"category" => "navt-links",
		"parent" => "navt-setup",
		"type" => "sub-section-4",),

	array("name" => "WordPress Link listing style in Top Navigation Bar",
		"desc" => "You can choose how to show links in your navigation bar. By default a single tab for links is shown in the navigation bar.",
		"id" => $shortname . "_navt_links_style",
		"parent" => "navt-setup",
		"grouping" => "navt-links",
		"type" => "radio",
		"options" => array("flattened" => "<div class='picture'><img src='" . get_template_directory_uri() . "/admin/images/nav-link-flat.jpg' alt='Flattened'/><p>Show the links in the navigation bar</p></div>",
			"rolled-up" => "<div class='picture'><img src='" . get_template_directory_uri() . "/admin/images/nav-link-roll-up.jpg' alt='Flattened'/><p>Show a single tab called \"Links\" (or whatever you want to call it) and build a drop-down under it</p></div>"),
		"std" => "rolled-up"),

	array("name" => "\"Links\" tab title",
		"desc" => "In the above option if you have chosen to show a single tab for WordPress links and build a drop-down under it, you can set the title for that tab.
				This setting is ignored if you have chosen to display individual links in the navigation bar.",
		"id" => $shortname . "_navt_links_tab_title",
		"parent" => "navt-setup",
		"grouping" => "navt-links",
		"type" => "text",
		"std" => "Links"),

	array("name" => "\"Links\" tab link",
		"desc" => "If you have a specific page that you want to go to upon clicking the Links tab, set the full URL here.
				This setting is ignored if you have chosen to display top level links in the navigation bar.",
		"id" => $shortname . "_navt_links_tab_link",
		"parent" => "navt-setup",
		"grouping" => "navt-links",
		"type" => "text",
		"hint" => "Enter the full URL, including http://",
		"std" => ""),

	array("name" => "Links in Navigation Bar - All or Selected",
		"desc" => "Choose which links you want to display",
		"id" => $shortname . "_navt_links_all_sel",
		"parent" => "navt-setup",
		"grouping" => "navt-links",
		"type" => "radio",
		"options" => array("all" => "Include all, ignoring next option", "selected" => "Include selections from the next option",
			"exclude-all" => "Exclude all, ignoring next option", "exclude-selected" => "Exclude selections from the next option"),
		"std" => "selected"),

	array("name" => "Select links to show in Navigation Bar",
		"desc" => "If you have too many links on your blog you might want to exclude some so that the navigation bar doesn't get ugly.
				All links are excluded by default. ",
		"id" => $shortname . "_navt_links",
		"parent" => "navt-setup",
		"grouping" => "navt-links",
		"export" => "ne",
		"type" => "multi-select",
		"options" => suf_get_formatted_link_array($shortname . "_navt_links")),

	array("name" => "WP 3.0 Navigation Menus",
		"desc" => "Control the display of inbuilt navigation menus (WP 3.0 and higher)",
		"category" => "navt-3menu",
		"parent" => "navt-setup",
		"type" => "sub-section-4",),

	array("name" => "WP 3.0 Navigation Menus - All or Selected",
		"desc" => "You can decide if you want to show all menus or selected menus in the navigation bar.
			If you choose 'All' your settings in the next option will be ignored. Also note that if you have added a menu to the navigation bar through the WP 3.0 menu administration page, it will show up even if excluded here.
			Note that this option is different from choosing 'Select All' in the next option, because this guarantees that always all are displayed, while the next option only ensures that all selections at the time of setup are displayed",
		"id" => $shortname . "_navt_menus_all_sel",
		"parent" => "navt-setup",
		"grouping" => "navt-3menu",
		"type" => "radio",
		"options" => array("all" => "All, ignoring next option", "selected" => "Selections from the next option"),
		"std" => "selected"),

	array("name" => "Select Menus to show",
		"desc" => "If you have too many menus on your blog you might want to exclude some so that the navigation bar doesn't get ugly.
			All menus are included by default. ",
		"id" => $shortname . "_navt_menus",
		"parent" => "navt-setup",
		"grouping" => "navt-3menu",
		"export" => "ne",
		"type" => "multi-select",
		"options" => suf_get_formatted_wp_menu_array($shortname . "_navt_menus")),

	array("name" => "Post and Page Bylines",
		"type" => "sub-section-3",
		"category" => "post-settings",
		"parent" => "blog-features"
	),

	array("name" => "Posts",
		"desc" => "Control positioning of post bylines",
		"category" => "post-settings-post",
		"parent" => "post-settings",
		"type" => "sub-section-4",),

	array("name" => "Position of meta information (including date)",
		"desc" => "Choose where you want information like Comments, Posted By etc to appear",
		"id" => $shortname . "_post_meta_position",
		"parent" => "post-settings",
		"grouping" => "post-settings-post",
		"type" => "radio",
		"options" => array("theme" => "Theme Default", "left-pullout" => "Pullout on the left (this will reduce your main column width)",
			"right-pullout" => "Pullout on the right side (this will reduce your main column width)", "corners" => "Show in corners above/below content"),
		"std" => "theme"),

	array("name" => "Show Categories for posts?",
		"desc" => "Links for the categories that the post is associated with show up under the title for all posts on the left side. Do you want to hide them?",
		"id" => $shortname . "_post_show_cats",
		"parent" => "post-settings",
		"grouping" => "post-settings-post",
		"type" => "select",
		"options" => array("show" => "Show Categories under title on the left side", "show-tright" => "Show Categories under title on the right side",
			"show-bleft" => "Show Categories above footer on the left side", "show-bright" => "Show Categories near footer on the right side", "hide" => "Hide Categories"),
		"std" => "show"),

	array("name" => "Show Comments link for Posts?",
		"desc" => "A link for comments shows up under the title for all posts on the right side. Do you want to hide it?",
		"id" => $shortname . "_post_show_comment",
		"parent" => "post-settings",
		"grouping" => "post-settings-post",
		"type" => "select",
		"options" => array("show-tleft" => "Show Comments link under title on the left side", "show" => "Show Comments link under title on the right side",
			"show-bleft" => "Show Comments link above footer on the left side", "show-bright" => "Show Comments link near footer on the right side", "hide" => "Hide Comments link"),
		"std" => "show"),

	array("name" => "Show \"Posted By\" for Posts?",
		"desc" => "Information about the poster shows up near the footer for all posts on the left side. Do you want to hide it?",
		"id" => $shortname . "_post_show_posted_by",
		"parent" => "post-settings",
		"grouping" => "post-settings-post",
		"type" => "select",
		"options" => array("show-tleft" => "Show Posted By under title on the left side", "show-tright" => "Show Posted By under title on the right side",
			"show" => "Show Posted By above footer on the left side", "show-bright" => "Show Posted By near footer on the right side", "hide" => "Hide Posted By"),
		"std" => "show"),

	array("name" => "Show Tags for posts?",
		"desc" => "Links for the tags that the post is associated with show up near the footer for all posts on the right side. Do you want to hide them?",
		"id" => $shortname . "_post_show_tags",
		"parent" => "post-settings",
		"grouping" => "post-settings-post",
		"type" => "select",
		"options" => array("show-tleft" => "Show Tags under title on the left side", "show-tright" => "Show Tags under title on the right side",
			"show-bleft" => "Show Tags above footer on the left side", "show" => "Show Tags near footer on the right side", "hide" => "Hide Tags"),
		"std" => "show"),

	array("name" => "Pages",
		"desc" => "Control positioning of page bylines",
		"category" => "post-settings-page",
		"parent" => "post-settings",
		"type" => "sub-section-4",),

	array("name" => "Position of meta information (including date)",
		"desc" => "Choose where you want information like Comments, Posted By etc to appear",
		"id" => $shortname . "_page_meta_position",
		"parent" => "post-settings",
		"grouping" => "post-settings-page",
		"type" => "radio",
		"options" => array("theme" => "Theme Default", "left-pullout" => "Pullout on the left (this will reduce your main column width)",
			"right-pullout" => "Pullout on the right side (this will reduce your main column width)", "corners" => "Show in corners above/below content"),
		"std" => "theme"),

	array("name" => "Show Comments link for Pages?",
		"desc" => "A link for comments shows up under the title for all pages on the right side. Do you want to hide it?",
		"id" => $shortname . "_page_show_comment",
		"parent" => "post-settings",
		"grouping" => "post-settings-page",
		"type" => "select",
		"options" => array("show-tleft" => "Show Comments link under title on the left side", "show" => "Show Comments link under title on the right side",
			"show-bleft" => "Show Comments link above footer on the left side", "show-bright" => "Show Comments link near footer on the right side", "hide" => "Hide Comments link"),
		"std" => "show"),

	array("name" => "Show \"Posted By\" for Pages?",
		"desc" => "Information about the poster shows up near the footer for all pages on the left side. Do you want to hide it?",
		"id" => $shortname . "_page_show_posted_by",
		"parent" => "post-settings",
		"grouping" => "post-settings-page",
		"type" => "select",
		"options" => array("show-tleft" => "Show Posted By under title on the left side", "show-tright" => "Show Posted By under title on the right side",
			"show" => "Show Posted By above footer on the left side", "show-bright" => "Show Posted By near footer on the right side", "hide" => "Hide Posted By"),
		"std" => "show"),

	array("name" => "Layout: Excerpt / List / Tile / Full",
		"type" => "sub-section-3",
		"category" => "excerpt-settings",
		"parent" => "blog-features"
	),

	array("name" => "Front Page settings",
		"desc" => "Control front page layout",
		"category" => "layout-front",
		"parent" => "excerpt-settings",
		"type" => "sub-section-4",),

	array("name" => "Layout Settings for the Front Page",
		"desc" => "By default for all posts on the front page, the complete contents are displayed.",
		"id" => $shortname . "_index_excerpt",
		"parent" => "excerpt-settings",
		"grouping" => "layout-front",
		"type" => "radio",
		"options" => array("content" => "Display full content", "excerpt" => "Display excerpt", "list" => "Display list", "tiles" => 'Display tiles'),
		"std" => "content"),

	array("name" => "Number of Full content posts on Front Page",
		"desc" => "In the Excerpt, List and Tile display you can choose to show the first few posts with full content. Set the number of posts for which you want the full content displayed (ignored if you select full content above): ",
		"id" => $shortname . "_index_fc_number",
		"parent" => "excerpt-settings",
		"grouping" => "layout-front",
		"type" => "select",
		"options" => array("0" => "0 (Zero)", "1" => "1 (One)", "2" => "2 (Two)", "3" => "3 (Three)", "4" => "4 (Four)",
			"5" => "5 (Five)", "6" => "6 (Six)", "7" => "7 (Seven)", "8" => "8 (Eight)", "9" => "9 (Nine)", "10" => "10 (Ten)"),
		"std" => "0"),

	array("name" => "Category Page settings",
		"desc" => "Control category page layout",
		"category" => "layout-cat",
		"parent" => "excerpt-settings",
		"type" => "sub-section-4",),

	array("name" => "Layout Settings for Categories",
		"desc" => "If you select a category, you can choose to show excerpts instead of full contents for each post. By default the complete contents are displayed. ",
		"id" => $shortname . "_category_excerpt",
		"parent" => "excerpt-settings",
		"grouping" => "layout-cat",
		"type" => "radio",
		"options" => array("content" => "Display full content", "excerpt" => "Display excerpt", "list" => "Display list", "tiles" => 'Display tiles'),
		"std" => "content"),

	array("name" => "Number of Full content posts for Categories",
		"desc" => "In the Excerpt, List and Tile display you can choose to show the first few posts with full content. Set the number of posts for which you want the full content displayed (ignored if you select full content above): ",
		"id" => $shortname . "_category_fc_number",
		"parent" => "excerpt-settings",
		"grouping" => "layout-cat",
		"type" => "select",
		"options" => array("0" => "0 (Zero)", "1" => "1 (One)", "2" => "2 (Two)", "3" => "3 (Three)", "4" => "4 (Four)",
			"5" => "5 (Five)", "6" => "6 (Six)", "7" => "7 (Seven)", "8" => "8 (Eight)", "9" => "9 (Nine)", "10" => "10 (Ten)"),
		"std" => "0"),

	array("name" => "Date-based Archive Page settings",
		"desc" => "Control date-based archive page layout",
		"category" => "layout-archive",
		"parent" => "excerpt-settings",
		"type" => "sub-section-4",),

	array("name" => "Layout Settings for Date-based Archives",
		"desc" => "If you select a month or a year, you can choose to show excerpts instead of full contents for each post. By default the complete contents are displayed. ",
		"id" => $shortname . "_archive_excerpt",
		"parent" => "excerpt-settings",
		"grouping" => "layout-archive",
		"type" => "radio",
		"options" => array("content" => "Display full content", "excerpt" => "Display excerpt", "list" => "Display list", "tiles" => 'Display tiles'),
		"std" => "content"),

	array("name" => "Number of Full content posts for date-based archives",
		"desc" => "In the Excerpt, List and Tile display you can choose to show the first few posts with full content. Set the number of posts for which you want the full content displayed (ignored if you select full content above): ",
		"id" => $shortname . "_archive_fc_number",
		"parent" => "excerpt-settings",
		"grouping" => "layout-archive",
		"type" => "select",
		"options" => array("0" => "0 (Zero)", "1" => "1 (One)", "2" => "2 (Two)", "3" => "3 (Three)", "4" => "4 (Four)",
			"5" => "5 (Five)", "6" => "6 (Six)", "7" => "7 (Seven)", "8" => "8 (Eight)", "9" => "9 (Nine)", "10" => "10 (Ten)"),
		"std" => "0"),

	array("name" => "Tag Page settings",
		"desc" => "Control tag page layout",
		"category" => "layout-tag",
		"parent" => "excerpt-settings",
		"type" => "sub-section-4",),

	array("name" => "Layout Settings for Tags",
		"desc" => "If you select a tag, you can choose to show excerpts instead of full contents for each post. By default the complete contents are displayed. ",
		"id" => $shortname . "_tag_excerpt",
		"parent" => "excerpt-settings",
		"grouping" => "layout-tag",
		"type" => "radio",
		"options" => array("content" => "Display full content", "excerpt" => "Display excerpt", "list" => "Display list", "tiles" => 'Display tiles'),
		"std" => "content"),

	array("name" => "Number of Full content posts for Tags",
		"desc" => "In the Excerpt, List and Tile display you can choose to show the first few posts with full content. Set the number of posts for which you want the full content displayed (ignored if you select full content above): ",
		"id" => $shortname . "_tag_fc_number",
		"parent" => "excerpt-settings",
		"grouping" => "layout-tag",
		"type" => "select",
		"options" => array("0" => "0 (Zero)", "1" => "1 (One)", "2" => "2 (Two)", "3" => "3 (Three)", "4" => "4 (Four)",
			"5" => "5 (Five)", "6" => "6 (Six)", "7" => "7 (Seven)", "8" => "8 (Eight)", "9" => "9 (Nine)", "10" => "10 (Ten)"),
		"std" => "0"),

	array("name" => "Search Page settings",
		"desc" => "Control search page layout",
		"category" => "layout-search",
		"parent" => "excerpt-settings",
		"type" => "sub-section-4",),

	array("name" => "Layout Settings for Search Results",
		"desc" => "When you perform a search the complete contents of the matching posts are displayed. You can change this to show only the excerpts. ",
		"id" => $shortname . "_search_excerpt",
		"parent" => "excerpt-settings",
		"grouping" => "layout-search",
		"type" => "radio",
		"options" => array("content" => "Display full content", "excerpt" => "Display excerpt", "list" => "Display list", "tiles" => 'Display tiles'),
		"std" => "content"),

	array("name" => "Number of Full content posts for Search Results",
		"desc" => "In the Excerpt, List and Tile display you can choose to show the first few posts with full content. Set the number of posts for which you want the full content displayed (ignored if you select full content above): ",
		"id" => $shortname . "_search_fc_number",
		"parent" => "excerpt-settings",
		"grouping" => "layout-search",
		"type" => "select",
		"options" => array("0" => "0 (Zero)", "1" => "1 (One)", "2" => "2 (Two)", "3" => "3 (Three)", "4" => "4 (Four)",
			"5" => "5 (Five)", "6" => "6 (Six)", "7" => "7 (Seven)", "8" => "8 (Eight)", "9" => "9 (Nine)", "10" => "10 (Ten)"),
		"std" => "0"),

	array("name" => "Author Page settings",
		"desc" => "Control author page layout",
		"category" => "layout-author",
		"parent" => "excerpt-settings",
		"type" => "sub-section-4",),

	array("name" => "Layout Settings for the Author Page",
		"desc" => "When you pull up the posts for an author the complete contents of the posts are displayed. You can change this to show only the excerpts. ",
		"id" => $shortname . "_author_excerpt",
		"parent" => "excerpt-settings",
		"grouping" => "layout-author",
		"type" => "radio",
		"options" => array("content" => "Display full content", "excerpt" => "Display excerpt", "list" => "Display list", "tiles" => 'Display tiles'),
		"std" => "content"),

	array("name" => "Number of Full content posts for Authors",
		"desc" => "In the Excerpt, List and Tile display you can choose to show the first few posts with full content. Set the number of posts for which you want the full content displayed (ignored if you select full content above): ",
		"id" => $shortname . "_author_fc_number",
		"parent" => "excerpt-settings",
		"grouping" => "layout-author",
		"type" => "select",
		"options" => array("0" => "0 (Zero)", "1" => "1 (One)", "2" => "2 (Two)", "3" => "3 (Three)", "4" => "4 (Four)",
			"5" => "5 (Five)", "6" => "6 (Six)", "7" => "7 (Seven)", "8" => "8 (Eight)", "9" => "9 (Nine)", "10" => "10 (Ten)"),
		"std" => "0"),

	array("name" => "General Excerpt settings",
		"desc" => "Control general settings for excerpts",
		"category" => "excerpt-gen",
		"parent" => "excerpt-settings",
		"type" => "sub-section-4",),

	array("name" => "Number of words in auto-generated excerpts (WordPress 2.9 and higher)",
		"desc" => "By default auto-generated excerpts in WordPress are 55 words long. You can set this length to anything you like:",
		"id" => $shortname . "_excerpt_custom_length",
		"parent" => "excerpt-settings",
		"grouping" => "excerpt-gen",
		"type" => "text",
		"hint" => "Enter the number of words here.",
		"std" => "55"),

	array("name" => "Replacement text for \"[...]\" in excerpts (WordPress 2.9 and higher)",
		"desc" => "By default auto-generated excerpts in WordPress end with \"[...]\". You can change this:",
		"id" => $shortname . "_excerpt_custom_more_text",
		"parent" => "excerpt-settings",
		"grouping" => "excerpt-gen",
		"type" => "text",
		"hint" => "Enter the replacement text here.",
		"std" => "[...]"),

	array("name" => "Thumbnail settings",
		"desc" => "Control settings for thumbnails",
		"category" => "excerpt-thumb",
		"parent" => "excerpt-settings",
		"type" => "sub-section-4",),

	array("name" => "Show thumbnails for excerpts",
		"desc" => "If you are retrieving an excerpt, you can display a thumbnail for it.
			WP 2.9 supports native thumbnails. So if you have a Post Thumbnail set in your Edit Page or Edit Post screen (right side), this takes precedence.
			Otherwise the thumbnail is picked up from the URL provided in the \"Thumbnail\" setting of a post or a page:",
		"id" => $shortname . "_show_excerpt_thumbnail",
		"parent" => "excerpt-settings",
		"grouping" => "excerpt-thumb",
		"type" => "radio",
		"options" => array("show" => "Display Thumbnail, if available", "hide" => "Hide Thumbnail"),
		"std" => "show"),

	array("name" => "Show thumbnails for full content (WordPress 2.9 and higher)",
		"desc" => "WP 2.9 introduced native thumbnail capability. The thumbnail can be defined for both excerpts and full content.
			For excerpts the previous setting takes effect. You can show thumbnails for posts by controlling the setting here.
			Note that to use this feature your thumbnail must be defined in the \"Post Thumbnail\" section of your Edit Page or Edit Post screen:",
		"id" => $shortname . "_show_content_thumbnail",
		"parent" => "excerpt-settings",
		"grouping" => "excerpt-thumb",
		"type" => "radio",
		"options" => array("show" => "Display Thumbnail, if available", "hide" => "Hide Thumbnail"),
		"std" => "show"),

	array("name" => "Use TimThumb for resizing",
		"desc" => "The default WP implementation of thumbnail resizing has some limitations.
			Suffusion uses <a href='http://www.darrenhoyt.com/2008/04/02/timthumb-php-script-released/'>TimThumb</a> to address the shortcomings.
			Note that if you are linking to an image on an external site, TimThumb will download a copy of that image locally.
			<b>Make sure that you are not violating any copyright.</b> You can disable TimThumb if you face issues:",
		"id" => $shortname . "_img_use_resizing_script",
		"parent" => "excerpt-settings",
		"grouping" => "excerpt-thumb",
		"type" => "radio",
		"options" => array("timthumb" => "Use TimThumb", "wp" => "Use the default WordPress resizing"),
		"std" => "timthumb"),

	array("name" => "Use TimThumb 'Zoom Crop'",
		"desc" => "Try changing this setting if you feel your images are not being cropped correctly:",
		"id" => $shortname . "_excerpt_tt_zc",
		"parent" => "excerpt-settings",
		"grouping" => "excerpt-thumb",
		"type" => "radio",
		"options" => array("0" => "No zoom crop", "1" => "Use zoom crop"),
		"std" => "1"),

	array("name" => "Set TimThumb compression quality",
		"desc" => "Adjust this if you want to change the quality of your compressed image. The default is 75:",
		"id" => $shortname . "_excerpt_tt_quality",
		"parent" => "excerpt-settings",
		"grouping" => "excerpt-thumb",
		"type" => "slider",
		"options" => array("range" => "min", "min" => 25, "max" => 100, "step" => 1, "size" => "400px", "unit" => ""),
		"std" => 75),

	array("name" => "Thumbnail alignment in excerpts",
		"desc" => "You can set the thumbnail (if present) to appear either on the left or on the right of the excerpt:",
		"id" => $shortname . "_excerpt_thumbnail_alignment",
		"parent" => "excerpt-settings",
		"grouping" => "excerpt-thumb",
		"type" => "radio",
		"options" => array("left" => "Show thumbnail on the left of the excerpt", "right" => "Show thumbnail on the right of the excerpt"),
		"std" => "left"),

	array("name" => "Thumbnail size in excerpts",
		"desc" => "You can set the size of the thumbnail (if present). This is the size of the thumbnail in the excerpt:",
		"id" => $shortname . "_excerpt_thumbnail_size",
		"parent" => "excerpt-settings",
		"grouping" => "excerpt-thumb",
		"type" => "radio",
		"options" => array("thumbnail" => "Thumbnail size, as defined in Settings -&gt; Media",
			"medium" => "Medium size, as defined in Settings -&gt; Media",
			"large" => "Large size, as defined in Settings -&gt; Media",
			"full" => "Full size of the image",
			"custom" => "Custom size defined below"),
		"std" => "thumbnail"),

	array("name" => "Custom width of thumbnail",
		"desc" => "If you have chosen to define a custom size above, please enter the width in pixels:",
		"id" => $shortname . "_excerpt_thumbnail_custom_width",
		"parent" => "excerpt-settings",
		"grouping" => "excerpt-thumb",
		"type" => "text",
		"hint" => "Enter the number of pixels here (don't enter 'px'). Non-integers will be ignored.",
		"std" => "200"),

	array("name" => "Custom height of thumbnail",
		"desc" => "If you have chosen to define a custom size above, please enter the height in pixels:",
		"id" => $shortname . "_excerpt_thumbnail_custom_height",
		"parent" => "excerpt-settings",
		"grouping" => "excerpt-thumb",
		"type" => "text",
		"hint" => "Enter the number of pixels here (don't enter 'px'). Non-integers will be ignored.",
		"std" => "200"),

	array("name" => "List layout settings",
		"desc" => "Control settings for \"Display List\" option ",
		"category" => "layout-list",
		"parent" => "excerpt-settings",
		"type" => "sub-section-4",),

	array("name" => "Number of posts in \"Display List\" option",
		"desc" => "If you have selected \"Display List\" for any of the views above, you can control the number of posts to show per page:",
		"id" => $shortname . "_excerpt_list_count",
		"parent" => "excerpt-settings",
		"grouping" => "layout-list",
		"type" => "radio",
		"options" => array("all" => "Show all results",
			"posts-per-page" => "Show as many posts as allowed in the 'Posts Per Page' setting in Settings -&gt; Reading",),
		"std" => "all"),

	array("name" => "List style in \"Display List\" option",
		"desc" => "If you have selected \"Display List\" for any of the views above, you can choose to show ordered or unordered lists:",
		"id" => $shortname . "_excerpt_list_style",
		"parent" => "excerpt-settings",
		"grouping" => "layout-list",
		"type" => "radio",
		"options" => array("ul" => "Unordered List", "ol" => "Ordered List",),
		"std" => "ul"),

	array("name" => "Tile layout settings",
		"desc" => "Control settings for \"Display Tiles\" option ",
		"category" => "layout-tiles",
		"parent" => "excerpt-settings",
		"type" => "sub-section-4",),

	array("name" => "Number of excerpts per row in \"Display Tiles\" option",
		"desc" => "If you have selected \"Display Tiles\" option for any of the views above, you can control the number of excerpts (tiles) to show per row:",
		"id" => $shortname . "_tile_excerpts_per_row",
		"parent" => "excerpt-settings",
		"grouping" => "layout-tiles",
		"type" => "select",
		"options" => array("1" => "1 (One)", "2" => "2 (Two)", "3" => "3 (Three)", "4" => "4 (Four)", "5" => "5 (Five)", "6" => "6 (Six)", "7" => "7 (Seven)",
			"8" => "8 (Eight)", "9" => "9 (Nine)", "10" => "10 (Ten)"),
		"std" => "3"),

	array("name" => "Thumbnail container for excerpts",
		"desc" => "You can show thumbnails for excerpts in the tiles display: ",
		"id" => $shortname . "_tile_images_enabled",
		"parent" => "excerpt-settings",
		"grouping" => "layout-tiles",
		"type" => "radio",
		"options" => array("show" => "Always show Thumbnail container", "hide" => "Always hide Thumbnail container",
			"hide-empty" => "Hide Thumbnail container if there is no thumbnail"),
		"std" => "show"),

	array("name" => "Thumbnail container height for excerpts",
		"desc" => "For the purposes of visual consistency you can set the height of the box in which the thumbnail will be placed. Your thumbnail will be \"cropped\" to this height: ",
		"id" => $shortname . "_tile_image_box_height",
		"parent" => "excerpt-settings",
		"grouping" => "layout-tiles",
		"type" => "text",
		"hint" => "Enter the number of pixels here (don't enter 'px'). Non-integers will be ignored.",
		"std" => "100"),

	array("name" => "Display Tiles - Alignment of post title in Excerpts",
		"desc" => "You can set the alignment for the post title in the excerpts: ",
		"id" => $shortname . "_tile_title_alignment",
		"parent" => "excerpt-settings",
		"grouping" => "layout-tiles",
		"type" => "radio",
		"options" => array("left" => "Left", "center" => "Center", "right" => "Right"),
		"std" => "left"),

	array("name" => "SEO / Meta Settings",
		"type" => "sub-section-3",
		"category" => "seo-settings",
		"parent" => "blog-features"
	),

	array("name" => "Enable SEO settings for the theme?",
		"desc" => "Suffusion comes bundled with SEO settings. You should turn these off if you are using a plugin like All-in-One SEO or Platinum SEO. ",
		"id" => $shortname . "_seo_enabled",
		"parent" => "seo-settings",
		"type" => "radio",
		"options" => array("enabled" => "Enable SEO", "disabled" => "Disable SEO"),
		"std" => "enabled"),

	array("name" => "Select Meta tags",
		"desc" => "The options you pick here will be applied to the document headers. Each option corresponds to a meta tag that the theme creates: ",
		"id" => $shortname . "_seo_all_settings",
		"parent" => "seo-settings",
		"type" => "multi-select",
		"options" => suf_get_formatted_options_array($shortname . "_seo_all_settings", array('generator' => 'Show WordPress version tags',
			'theme' => 'Include Suffusion theme information tags',
			'robots' => 'Hide page from Google and other search engines',
			'author' => "Include author information",
			'copyright' => 'Include copyright info',
			'revised' => "Include page revision info")),
		"std" => ""
	),

	array("name" => "Title style",
		"desc" => "The best practices in SEO suggest that your article title should be the first text in your page title.
			For category views etc the article title is the name of category. You can pick your setting: ",
		"id" => $shortname . "_seo_title_style",
		"parent" => "seo-settings",
		"type" => "radio",
		"options" => array('page-blog' => 'Show the page title followed by the blog title',
			'blog-page' => 'Show the blog title followed by the page title', 'page' => 'Show the page title only'),
		"std" => "page-blog"),

	array("name" => "Title Separator",
		"desc" => "This is the symbol that appears as a separator between the page title and blog title (based on your selection in the parevious option):",
		"id" => $shortname . "_seo_title_separator",
		"parent" => "seo-settings",
		"type" => "text",
		"hint" => "Use &amp;bull; for &bull;, &amp;gt; for &gt; and &amp;raquo; for &raquo;",
		"std" => "&raquo;"),

	array("name" => "Blog description / subtitle in page title on home page",
		"id" => $shortname . "_seo_show_subtitle",
		"parent" => "seo-settings",
		"type" => "radio",
		"options" => array('show' => 'Include blog subtitle in page title',
			'hide' => 'Hide blog subtitle in page title'),
		"std" => "hide"),

	array("name" => "Page numbers in title",
		"id" => $shortname . "_seo_show_page_num",
		"parent" => "seo-settings",
		"type" => "radio",
		"options" => array('show' => 'Include page number in the title on the second page and higher',
			'hide' => 'Hide page number in the title'),
		"std" => "show"),

	array("name" => "Homepage Meta Description",
		"desc" => "Enter a brief description for your home page, not more than 30 words:",
		"id" => $shortname . "_seo_meta_description",
		"parent" => "seo-settings",
		"hint" => "Leave blank if you don't want a meta description",
		"type" => "textarea",
		"std" => ""),

	array("name" => "Homepage Meta Keywords",
		"desc" => "Enter a comma-separated list of keywords that best describe your blog:",
		"id" => $shortname . "_seo_meta_keywords",
		"parent" => "seo-settings",
		"type" => "textarea",
		"std" => "",
		"hint" => "Leave blank if you don't want meta keywords"),

	array("name" => "Comment Settings",
		"type" => "sub-section-3",
		"category" => "comment-settings",
		"parent" => "blog-features"
	),

	array("name" => "Hide \"Comment form closed\" Message on Pages",
		"desc" => "You can decide if you want to show the \"Comment form closed\" message on pages.
			If you choose 'All' your settings in the next option will be ignored.
			Note that this option is different from choosing 'Select All' in the next option, because this guarantees that always all are selected, while the next option only ensures that all selections at the time of setup are stored",
		"id" => $shortname . "_comments_disabled_all_sel",
		"parent" => "comment-settings",
		"type" => "radio",
		"options" => array("all" => "All, ignoring next option", "selected" => "Selections from the next option"),
		"std" => "all"),

	array("name" => "Select pages to hide \"Comment form closed\" message",
		"desc" => "If you disable comments on a page, a \"Comment form closed\" message shows up. " .
				"You can choose to hide this message for selected pages, if you think it makes your page look too \"blog-like\". " .
				"If you select a page from the list below it will not show the \"Comment form closed\" message. " .
				"Note that if comments are <b>enabled</b> for a page, selecting it here will not make a difference. ",
		"id" => $shortname . "_comments_disabled",
		"parent" => "comment-settings",
		"export" => "ne",
		"type" => "multi-select",
		"options" => suf_get_formatted_page_array($shortname . "_comments_disabled")),

	array("name" => "Hide \"Comment form closed\" Message on Posts",
		"desc" => "If you disable comments on a post, you can make a  \"Comment form closed\" message show up. " .
				"You can choose to hide this message for all such posts, if you think it makes your page look too \"blog-like\". " .
				"Note that if comments are <b>enabled</b> for a post, setting this option will not make a difference. ",
		"id" => $shortname . "_comments_disabled_msg_for_posts",
		"parent" => "comment-settings",
		"type" => "radio",
		"options" => array('show' => 'Show the message', 'hide' => 'Hide the message'),
		"std" => "show"),

	array("name" => "Show Trackbacks and Pingbacks?",
		"desc" => "By default Trackbacks and Pingbacks to your blog posts show up along with other comments. ",
		"id" => $shortname . "_show_track_ping",
		"parent" => "comment-settings",
		"type" => "radio",
		"options" => array("show" => "Show all Trackbacks and Pingbacks with comments", "hide" => "Don't show Trackbacks and Pingbacks",
			"separate" => "Show Trackbacks and Pingbacks, but separate them from the comments"),
		"std" => "show"),

	array("name" => "Allow Replies for Trackbacks and Pingbacks?",
		"desc" => "For comments that are trackbacks or pingbacks you might want to hide the \"Reply\" link: ",
		"id" => $shortname . "_show_hide_reply_link_for_pings",
		"parent" => "comment-settings",
		"type" => "radio",
		"options" => array("allow" => "Allow replies to Trackbacks and Pingbacks", "disallow" => "Don't allow replies to Trackbacks and Pingbacks"),
		"std" => "disallow"),

	array("name" => "Comment form labels styles",
		"desc" => "You can choose to have theme-based styles for labels in your comment form, or leave them unstyled. The theme-based style is more colorful (which you may or may not prefer): ",
		"id" => $shortname . "_comment_label_styles",
		"parent" => "comment-settings",
		"type" => "radio",
		"options" => array("plain" => "Plain (unstyled, default)", "theme" => "Theme-based style"),
		"std" => "plain"),

	array("name" => "Comment form labels",
		"desc" => "Setup your comment form labels here",
		"category" => "comment-labels",
		"parent" => "comment-settings",
		"type" => "sub-section-4",),

	array("name" => "Name",
		"desc" => "Label for 'Name': ",
		"id" => $shortname . "_comment_label_name",
		"parent" => "comment-settings",
		"grouping" => "comment-labels",
		"type" => "text",
		"std" => esc_attr($suffusion_comment_label_name)),

	array("name" => "Name Required",
		"desc" => "Label to display to show that the name is required: ",
		"id" => $shortname . "_comment_label_name_req",
		"parent" => "comment-settings",
		"grouping" => "comment-labels",
		"type" => "text",
		"std" => esc_attr($suffusion_comment_label_req)),

	array("name" => "Email",
		"desc" => "Label for 'Email': ",
		"id" => $shortname . "_comment_label_email",
		"parent" => "comment-settings",
		"grouping" => "comment-labels",
		"type" => "text",
		"std" => esc_attr($suffusion_comment_label_email)),

	array("name" => "Email Required",
		"desc" => "Label to display to show that the email is required: ",
		"id" => $shortname . "_comment_label_email_req",
		"parent" => "comment-settings",
		"grouping" => "comment-labels",
		"type" => "text",
		"std" => esc_attr($suffusion_comment_label_req)),

	array("name" => "URI",
		"desc" => "Label for 'URI': ",
		"id" => $shortname . "_comment_label_uri",
		"parent" => "comment-settings",
		"grouping" => "comment-labels",
		"type" => "text",
		"std" => esc_attr($suffusion_comment_label_uri)),

	array("name" => "Your Comment",
		"desc" => "Label for 'Your Comment': ",
		"id" => $shortname . "_comment_label_your_comment",
		"parent" => "comment-settings",
		"grouping" => "comment-labels",
		"type" => "text",
		"std" => esc_attr($suffusion_comment_label_your_comment)),

	array("name" => "Featured Content",
		"type" => "sub-section-3",
		"category" => "featured-settings",
		"parent" => "blog-features"
	),

	array("name" => "Showing Featured Posts",
		"desc" => "Featured posts help bring certain posts to the top of your blog. Suffusion supports Featured Posts in multiple ways:
				<ul class='margin-20'>
					<li>Sticky Posts</li>
					<li>Selected Categories</li>
					<li>Selected Posts</li>
					<li>Selected Pages</li>
					<li>Selected Tags</li>
				</ul>
				Suffusion uses the excellent <a href='http://www.malsup.com/jquery/cycle/'>JQuery Cycle</a> to create a Featured section above your posts.
				Additionally you can define a \"Featured Image\" (preferably as wide as your blog posts). If you don't associate a featured image, the thumbnail will be picked.
				And if you don't provide a thumbnail, the first attached image will be used. Note, though, that not having a featured image will generate thumbnail size images, displaying a lot of blank space.
				Good practices:
				<ul class='margin-20'>
					<li>Use featured images for every post that you want to show in your featured section.</li>
					<li>Define featured images that are at least as wide as your posts.</li>
					<li>Don't use too many featured posts. Remember that this section should have useful information, not all information. Having too many posts will make your script sluggish.</li>
				</ul>
				",
		"parent" => "featured-settings",
		"type" => "blurb"),

	array("name" => "Where to Show",
		"desc" => "Where do you want the Featured Content to appear?",
		"category" => "fc-where",
		"parent" => "featured-settings",
		"type" => "sub-section-4",),

	array("name" => "Main (default) page",
		"desc" => "You can enable the Featured Posts slider on your main page. This is also the default page: ",
		"id" => $shortname . "_featured_index_view",
		"parent" => "featured-settings",
		"grouping" => "fc-where",
		"type" => "radio",
		"options" => array("enabled" => "Enabled", "disabled" => "Disabled"),
		"std" => "disabled"),

	array("name" => "Category view",
		"desc" => "You can enable the Featured Posts slider for your category view. This way you will see the featured section whenever you are looking at posts in a particular category: ",
		"id" => $shortname . "_featured_category_view",
		"parent" => "featured-settings",
		"grouping" => "fc-where",
		"type" => "radio",
		"options" => array("enabled" => "Enabled", "disabled" => "Disabled"),
		"std" => "disabled"),

	array("name" => "Tag view",
		"desc" => "You can enable the Featured Posts slider for your tag view. This way you will see the featured section whenever you are looking at posts with a particular tag: ",
		"id" => $shortname . "_featured_tag_view",
		"parent" => "featured-settings",
		"grouping" => "fc-where",
		"type" => "radio",
		"options" => array("enabled" => "Enabled", "disabled" => "Disabled"),
		"std" => "disabled"),

	array("name" => "Author view",
		"desc" => "You can enable the Featured Posts slider for your author view. This way you will see the featured section whenever you are looking at an author page: ",
		"id" => $shortname . "_featured_author_view",
		"parent" => "featured-settings",
		"grouping" => "fc-where",
		"type" => "radio",
		"options" => array("enabled" => "Enabled", "disabled" => "Disabled"),
		"std" => "disabled"),

	array("name" => "Search view",
		"desc" => "You can enable the Featured Posts slider for your search view. This way you will see the featured section whenever you are looking at search results: ",
		"id" => $shortname . "_featured_search_view",
		"parent" => "featured-settings",
		"grouping" => "fc-where",
		"type" => "radio",
		"options" => array("enabled" => "Enabled", "disabled" => "Disabled"),
		"std" => "disabled"),

	array("name" => "Time archive view",
		"desc" => "You can enable the Featured Posts slider for your tiem archive (time / date / day / month / year) view. This way you will see the featured section whenever you are looking at time-based archives: ",
		"id" => $shortname . "_featured_time_view",
		"parent" => "featured-settings",
		"grouping" => "fc-where",
		"type" => "radio",
		"options" => array("enabled" => "Enabled", "disabled" => "Disabled"),
		"std" => "disabled"),

	array("name" => "Static Pages with Featured Content",
		"desc" => "By default the featured content is not shown on static pages. You can choose the pages in your blog that will contain the Featured Posts: ",
		"id" => $shortname . "_featured_pages_with_fc",
		"parent" => "featured-settings",
		"grouping" => "fc-where",
		"export" => "ne",
		"type" => "multi-select",
		"options" => suf_get_formatted_page_array($shortname . "_featured_pages_with_fc")),

	array("name" => "What to Show",
		"desc" => "What do you want to display in the Featured Content section?",
		"category" => "fc-what",
		"parent" => "featured-settings",
		"type" => "sub-section-4",),

	array("name" => "Number of Posts",
		"desc" => "By default this is limited to the number of posts you allow per page: ",
		"id" => $shortname . "_featured_num_posts",
		"parent" => "featured-settings",
		"grouping" => "fc-what",
		"type" => "text",
		"hint" => "Enter the number here. Please enter positive numeric values only",
		"std" => get_option('posts_per_page')),

	array("name" => "Show Duplicate Posts",
		"desc" => "Show posts from the featured content section in the rest of the body: ",
		"id" => $shortname . "_featured_show_dupes",
		"parent" => "featured-settings",
		"grouping" => "fc-what",
		"type" => "radio",
		"options" => array("show" => "Show duplicate posts", "hide" => "Hide duplicate posts"),
		"std" => "hide"),

	array("name" => "Show Sticky Posts",
		"desc" => "To make a post \"sticky\" go to the \"Edit Posts\" menu, then click on the \"Visibility\" option in the publish section and
				select \"Stick this post to the front page\": ",
		"id" => $shortname . "_featured_allow_sticky",
		"parent" => "featured-settings",
		"grouping" => "fc-what",
		"type" => "radio",
		"options" => array("show" => "Show sticky posts", "hide" => "Hide sticky posts"),
		"std" => "show"),

	array("name" => "Show Latest Posts?",
		"id" => $shortname . "_featured_show_latest",
		"parent" => "featured-settings",
		"grouping" => "fc-what",
		"type" => "radio",
		"options" => array("show" => "Show latest posts", "hide" => "Hide latest posts"),
		"std" => "hide"),

	array("name" => "Number of Latest Posts",
		"desc" => "This is not relevant if you are hiding latest posts.
				In case the number of latest posts is higher than the total number of posts, this setting is ignored: ",
		"id" => $shortname . "_featured_num_latest_posts",
		"parent" => "featured-settings",
		"grouping" => "fc-what",
		"type" => "text",
		"hint" => "Enter the number here. Please enter positive numeric values only",
		"std" => 5),

	array("name" => "Select Categories",
		"desc" => "In addition to sticky posts you can include posts from selected categories in the featured posts slider.
				By default no category is selected: ",
		"id" => $shortname . "_featured_selected_categories",
		"parent" => "featured-settings",
		"grouping" => "fc-what",
		"export" => "ne",
		"type" => "multi-select",
		"options" => suf_get_formatted_category_array($shortname . "_featured_selected_categories")),

	array("name" => "Select Pages",
		"desc" => "Note that the inclusion is NOT hierarchical here. By default no page is selected: ",
		"id" => $shortname . "_featured_selected_pages",
		"parent" => "featured-settings",
		"grouping" => "fc-what",
		"export" => "ne",
		"type" => "multi-select",
		"options" => suf_get_formatted_page_array($shortname . "_featured_selected_pages")),

	array("name" => "Posts to show",
		"desc" => "Include a comma-separated list of post ids you want to include in the featured posts: ",
		"id" => $shortname . "_featured_selected_posts",
		"parent" => "featured-settings",
		"grouping" => "fc-what",
		"type" => "text",
		"std" => ""),

	array("name" => "Tags to show",
		"desc" => "Include a comma-separated list of tags you want to include in the featured posts: ",
		"id" => $shortname . "_featured_selected_tags",
		"parent" => "featured-settings",
		"grouping" => "fc-what",
		"type" => "text",
		"std" => ""),

	array("name" => "How to Show",
		"desc" => "Set the visual effects of the featured content section here",
		"category" => "fc-how",
		"parent" => "featured-settings",
		"type" => "sub-section-4",),

	array("name" => "Use \"Lite\" version of JQuery Cycle?",
		"desc" => "If you are using the 'Fade' transition below and you don't want the post index, you should use the Lite version of the JQuery Cycle plugin. It is much smaller: ",
		"id" => $shortname . "_featured_use_lite",
		"parent" => "featured-settings",
		"grouping" => "fc-how",
		"type" => "radio",
		"options" => array("lite" => "Use Lite version (4 KB)", "regular" => "Use Regular version (29 KB)"),
		"std" => "regular"),

	array("name" => "Featured Posts - Transition Effects",
		"desc" => "You can pick the effect you want to use for your featured posts' transitions. These are effects provided by the JQuery Cycle script.
				Note that not all effects will look good on your blog. You should pick the one that best suits your needs: ",
		"id" => $shortname . "_featured_fx",
		"parent" => "featured-settings",
		"grouping" => "fc-how",
		"type" => "radio",
		"options" => array("fade" => "Fade In", "scrollUp" => "Scroll Up", "scrollDown" => "Scroll Down", "scrollLeft" => "Scroll Left", "scrollRight" => "Scroll Right",
			"scrollHorz" => "Scroll Horizontally", "scrollVert" => "Scroll Vertically",
			"slideX" => "Slide in and back horizontally", "slideY" => "Slide in and back vertically",
			"turnUp" => "Turn Upwards", "turnDown" => "Turn Downwards", "turnLeft" => "Turn Leftwards", "turnRight" => "Turn Rightwards",
			"zoom" => "Zoom", "fadeZoom" => "Zoom and Fade", "blindX" => "Vertical Blinds", "blindY" => "Horizontal Blinds", "blindZ" => "Diagonal Blinds",
			"growX" => "Grow horizontally from center", "growY" => "Grow vertically from center",
			"curtainX" => "Squeeze in both edges horizontally", "curtainY" => "Squeeze in both edges vertically",
			"cover" => "Current post is covered by next post", "uncover" => "Current post moves off next post", "wipe" => "Wipe",
		),
		"std" => "fade"),

	array("name" => "Featured Posts - Image synchronization",
		"desc" => "By default a new image starts showing only when the old one has cleared. You can change this behavior: ",
		"id" => $shortname . "_featured_sync",
		"parent" => "featured-settings",
		"grouping" => "fc-how",
		"type" => "radio",
		"options" => array("0" => "Show new image only after old one has cleared out fully", "1" => "Start showing new image as the old one starts clearing out"),
		"std" => "0"),

	array("name" => "Featured Posts - Time for each post display",
		"desc" => "The posts in the Featured Posts are each displayed for 4000 milliseconds (4 seconds). You can change this interval: ",
		"id" => $shortname . "_featured_interval",
		"parent" => "featured-settings",
		"grouping" => "fc-how",
		"type" => "text",
		"hint" => "Enter the time in milliseconds (don't enter \"ms\"!)",
		"std" => "4000"),

	array("name" => "Featured Posts - Transition speed for post",
		"desc" => "Depending on the transition effect you have chosen you may want to speed up or slow down your transition. Set the duration of the transition effect here: ",
		"id" => $shortname . "_featured_transition_speed",
		"parent" => "featured-settings",
		"grouping" => "fc-how",
		"type" => "text",
		"hint" => "Enter the time in milliseconds (don't enter \"ms\"!)",
		"std" => "1000"),

	array("name" => "Height of the Featured Posts section",
		"desc" => "The Featured Posts section is 250px high by default. You can change this setting depending on the size of your featuerd images.",
		"id" => $shortname . "_featured_height",
		"parent" => "featured-settings",
		"grouping" => "fc-how",
		"type" => "text",
		"hint" => "Enter the number of pixels here (don't enter 'px'). Non-integers will be ignored.",
		"std" => "250"),

	array("name" => "Featured Posts - Show Border",
		"desc" => "You can opt to show a border for your featured posts section: ",
		"id" => $shortname . "_featured_show_border",
		"parent" => "featured-settings",
		"grouping" => "fc-how",
		"type" => "radio",
		"options" => array("show" => "Show border", "hide" => "Hide border"),
		"std" => "show"),

	array("name" => "Image size in featured content",
		"desc" => "You can set the size of the featured image (if present):",
		"id" => $shortname . "_featured_image_size",
		"parent" => "featured-settings",
		"grouping" => "fc-how",
		"type" => "radio",
		"options" => array("full" => "Full size of the image",
			"custom" => "Custom size defined below"),
		"std" => "full"),

	array("name" => "Custom width of featured image",
		"desc" => "If you have chosen to define a custom size above, please enter the width in pixels:",
		"id" => $shortname . "_featured_image_custom_width",
		"parent" => "featured-settings",
		"grouping" => "fc-how",
		"type" => "text",
		"hint" => "Enter the number of pixels here (don't enter 'px'). Non-integers will be ignored.",
		"std" => "200"),

	array("name" => "Custom height of featured image",
		"desc" => "If you have chosen to define a custom size above, please enter the height in pixels:",
		"id" => $shortname . "_featured_image_custom_height",
		"parent" => "featured-settings",
		"grouping" => "fc-how",
		"type" => "text",
		"hint" => "Enter the number of pixels here (don't enter 'px'). Non-integers will be ignored.",
		"std" => "200"),

	array("name" => "Featured Posts - Display Text",
		"desc" => "You can decide what you want to include in your text display for the featured content. This text is laid over the featured image: ",
		"id" => $shortname . "_featured_excerpt_type",
		"parent" => "featured-settings",
		"grouping" => "fc-how",
		"type" => "radio",
		"options" => array("title-excerpt" => "Show post title and excerpt (default)", "title" => "Show post title only (no excerpt)",
			"excerpt" => "Show excerpt only (no title)", "none" => "Don't show any text (useful if your images have text included)"),
		"std" => "title-excerpt"),

	array("name" => "Featured Posts - Position of Text",
		"desc" => "You can decide where you want your excerpt to appear on the featured posts section: ",
		"id" => $shortname . "_featured_excerpt_position",
		"parent" => "featured-settings",
		"grouping" => "fc-how",
		"type" => "radio",
		"options" => array("top" => "Top", "bottom" => "Bottom", "right" => "Right", "left" => "Left",
			"alttb" => "Alternate excerpt between top and bottom", "altlr" => "Alternate excerpt between left and right",
			"rotate" => "Rotate between the four positions"),
		"std" => "rotate"),

	array("name" => "Width of Text",
		"desc" => "You can define the width to use for excerpts. Note that this is relevant only if your excerpt is at the right or at the left of your featured posts.",
		"id" => $shortname . "_featured_excerpt_width",
		"parent" => "featured-settings",
		"grouping" => "fc-how",
		"type" => "text",
		"hint" => "Enter the number of pixels here (don't enter 'px'). Non-integers will be ignored.",
		"std" => "250"),

	array("name" => "Featured Posts - Text background color",
		"desc" => "Depending on the color of your featured images, you might want to choose a different background color for your excerpt in your featured posts. ",
		"id" => $shortname . "_featured_excerpt_bg_color",
		"grouping" => "fc-how",
		"parent" => "featured-settings",
		"type" => "color-picker",
		"std" => "222222"),

	array("name" => "Featured Posts - Text font color",
		"desc" => "Depending on the color of your featured images, you might want to choose a different font color for your excerpt in your featured posts. ",
		"id" => $shortname . "_featured_excerpt_font_color",
		"parent" => "featured-settings",
		"grouping" => "fc-how",
		"type" => "color-picker",
		"std" => "FFFFFF"),

	array("name" => "Featured Posts - Link font color",
		"desc" => "Depending on the color of your featured images, you might want to choose a different link font color in your excerpt in your featured posts. ",
		"id" => $shortname . "_featured_excerpt_link_color",
		"parent" => "featured-settings",
		"grouping" => "fc-how",
		"type" => "color-picker",
		"std" => "FFFFFF"),

	array("name" => "Featured Posts - Post Index",
		"desc" => "You can show a numbered listing of posts for your Featured Posts: ",
		"id" => $shortname . "_featured_pager",
		"parent" => "featured-settings",
		"grouping" => "fc-how",
		"type" => "radio",
		"options" => array("show" => "Show Post Index", "hide" => "Hide Post Index"),
		"std" => "show"),

	array("name" => "Featured Posts - Pause, Previous and Next Controls",
		"desc" => "In addition to the numbered listing of posts you can display a controller for showing links to \"Previous Post\", \"Pause\" and \"Next Post\": ",
		"id" => $shortname . "_featured_controller",
		"parent" => "featured-settings",
		"grouping" => "fc-how",
		"type" => "radio",
		"options" => array("show" => "Show Pause, Previous and Next Controls", "hide" => "Hide Pause, Previous and Next Controls"),
		"std" => "hide"),

	array("name" => "Tabbed Sidebar",
		"type" => "sub-section-3",
		"category" => "sbtab-settings",
		"parent" => "blog-features"
	),

	array("name" => "Enable Tabbed Sidebar?",
		"desc" => "Tabbed Sidebars, a.k.a. Tabbed Widgets are used to represent multiple widgets in a single tabbed window.",
		"id" => $shortname . "_sbtab_enabled",
		"parent" => "sbtab-settings",
		"type" => "radio",
		"note" => "If you have chosen to have 0 sidebars in your \"Sidebars and Widget Areas\" setup, this setting is irrelevant.",
		"options" => array("enabled" => "Enable Tabbed Sidebar", "disabled" => "Do not enable the Tabbed Sidebar"),
		"std" => "disabled"),

	array("name" => "Alignment of Tabbed Sidebar",
		"desc" => "Which side do you want your tabbed sidebar? Note that you need to have at least one sidebar enabled on the side that you are selecting here, or the other side might be used. ",
		"id" => $shortname . "_sbtab_alignment",
		"parent" => "sbtab-settings",
		"type" => "radio",
		"options" => array("right" => "Right", "left" => "Left"),
		"std" => "right"),

	array("name" => "Contents of Tabbed Sidebar",
		"desc" => "You can pick what you want to show in the tabbed sidebar: ",
		"id" => $shortname . "_sbtab_widgets",
		"parent" => "sbtab-settings",
		"type" => "multi-select",
		"options" => suffusion_get_formatted_sbtab_array('suf_sbtab_widgets', true)),

	array("name" => "Order of tabs in Tabbed Sidebar",
		"desc" => "You can define the order of the tabs in the tabbed sidebar: ",
		"id" => $shortname . "_sbtab_widget_order",
		"parent" => "sbtab-settings",
		"type" => "sortable-list",
		"std" => suffusion_tab_array_prepositions()),

	array("name" => "Tabbed Sidebar - Categories Title",
		"id" => $shortname . "_sbtab_categories_title",
		"parent" => "sbtab-settings",
		"type" => "text",
		"std" => $sidebar_tabs['categories']['title']),

	array("name" => "Tabbed Sidebar - List categories hierarchically?",
		"desc" => "You can decide if you want to list your categories in a hierarchical manner: ",
		"id" => $shortname . "_sbtab_categories_hierarchical",
		"parent" => "sbtab-settings",
		"type" => "radio",
		"options" => array("hierarchical" => "Categories listed hierarchically",
			"flat" => "Categories listed flat"),
		"std" => "hierarchical"),

	array("name" => "Tabbed Sidebar - Show post count for each category?",
		"desc" => "You can display the number of posts in each category. Categories with 0 posts are excluded: ",
		"id" => $shortname . "_sbtab_categories_post_count",
		"parent" => "sbtab-settings",
		"type" => "radio",
		"options" => array("show" => "Show Post Count",
			"hide" => "Hide Post Count"),
		"std" => "hide"),

	array("name" => "Tabbed Sidebar - Archives Title",
		"id" => $shortname . "_sbtab_archives_title",
		"parent" => "sbtab-settings",
		"type" => "text",
		"std" => $sidebar_tabs['archives']['title']),

	array("name" => "Tabbed Sidebar - Archive grouping",
		"desc" => "What kind of grouping do you want to display for your archives? ",
		"id" => $shortname . "_sbtab_archives_type",
		"parent" => "sbtab-settings",
		"type" => "radio",
		"options" => array("yearly" => "Yearly", "monthly" => "Monthly", "weekly" => "Weekly", "daily" => "Daily", "postbypost" => "Posts ordered by post date",
			"alpha" => "Posts ordered by post title"),
		"std" => "monthly"),

	array("name" => "Tabbed Sidebar - Archive list type",
		"desc" => "What kind of listing do you want for your archives? ",
		"id" => $shortname . "_sbtab_archives_list_type",
		"parent" => "sbtab-settings",
		"type" => "radio",
		"options" => array("html" => "A bullet list", "option" => "A dropdown list"),
		"std" => "html"),

	array("name" => "Tabbed Sidebar - Show post count for each archive?",
		"desc" => "You can display the number of posts in each archive. Archives with 0 posts are excluded: ",
		"id" => $shortname . "_sbtab_archives_post_count",
		"parent" => "sbtab-settings",
		"type" => "radio",
		"options" => array("show" => "Show Post Count",
			"hide" => "Hide Post Count"),
		"std" => "hide"),

	array("name" => "Tabbed Sidebar - Links Title",
		"id" => $shortname . "_sbtab_Links_title",
		"parent" => "sbtab-settings",
		"type" => "text",
		"std" => $sidebar_tabs['links']['title']),

	array("name" => "Tabbed Sidebar - Meta Title",
		"id" => $shortname . "_sbtab_meta_title",
		"parent" => "sbtab-settings",
		"type" => "text",
		"std" => $sidebar_tabs['meta']['title']),

	array("name" => "Tabbed Sidebar - Pages Title",
		"id" => $shortname . "_sbtab_pages_title",
		"parent" => "sbtab-settings",
		"type" => "text",
		"std" => $sidebar_tabs['pages']['title']),

	array("name" => "Tabbed Sidebar - Recent Comments Title",
		"id" => $shortname . "_sbtab_recent_comments_title",
		"parent" => "sbtab-settings",
		"type" => "text",
		"std" => $sidebar_tabs['recent_comments']['title']),

	array("name" => "Tabbed Sidebar - Recent Posts Title",
		"id" => $shortname . "_sbtab_recent_posts_title",
		"parent" => "sbtab-settings",
		"type" => "text",
		"std" => $sidebar_tabs['recent_posts']['title']),

	array("name" => "Tabbed Sidebar - Search Title",
		"id" => $shortname . "_sbtab_search_title",
		"parent" => "sbtab-settings",
		"type" => "text",
		"std" => $sidebar_tabs['search']['title']),

	array("name" => "Tabbed Sidebar - Tag Cloud Title",
		"id" => $shortname . "_sbtab_tag_cloud_title",
		"parent" => "sbtab-settings",
		"type" => "text",
		"std" => $sidebar_tabs['tag_cloud']['title']),

	array("name" => "Tabbed Sidebar - Custom Tab 1 Title",
		"id" => $shortname . "_sbtab_custom_tab_1_title",
		"parent" => "sbtab-settings",
		"type" => "text",
		"std" => $sidebar_tabs['custom_tab_1']['title']),

	array("name" => "Tabbed Sidebar - Custom Tab 1 Contents",
		"id" => $shortname . "_sbtab_custom_tab_1_contents",
		"parent" => "sbtab-settings",
		"type" => "textarea",
		"std" => ""),

	array("name" => "Tabbed Sidebar - Custom Tab 2 Title",
		"id" => $shortname . "_sbtab_custom_tab_2_title",
		"parent" => "sbtab-settings",
		"type" => "text",
		"std" => $sidebar_tabs['custom_tab_2']['title']),

	array("name" => "Tabbed Sidebar - Custom Tab 2 Contents",
		"id" => $shortname . "_sbtab_custom_tab_2_contents",
		"parent" => "sbtab-settings",
		"type" => "textarea",
		"std" => ""),

	array("name" => "Tabbed Sidebar - Custom Tab 3 Title",
		"id" => $shortname . "_sbtab_custom_tab_3_title",
		"parent" => "sbtab-settings",
		"type" => "text",
		"std" => $sidebar_tabs['custom_tab_3']['title']),

	array("name" => "Tabbed Sidebar - Custom Tab 3 Contents",
		"id" => $shortname . "_sbtab_custom_tab_3_contents",
		"parent" => "sbtab-settings",
		"type" => "textarea",
		"std" => ""),

	array("name" => "Tabbed Sidebar - Custom Tab 4 Title",
		"id" => $shortname . "_sbtab_custom_tab_4_title",
		"parent" => "sbtab-settings",
		"type" => "text",
		"std" => $sidebar_tabs['custom_tab_4']['title']),

	array("name" => "Tabbed Sidebar - Custom Tab 4 Contents",
		"id" => $shortname . "_sbtab_custom_tab_4_contents",
		"parent" => "sbtab-settings",
		"type" => "textarea",
		"std" => ""),

	array("name" => "Tabbed Sidebar - Custom Tab 5 Title",
		"id" => $shortname . "_sbtab_custom_tab_5_title",
		"parent" => "sbtab-settings",
		"type" => "text",
		"std" => $sidebar_tabs['custom_tab_5']['title']),

	array("name" => "Tabbed Sidebar - Custom Tab 5 Contents",
		"id" => $shortname . "_sbtab_custom_tab_5_contents",
		"parent" => "sbtab-settings",
		"type" => "textarea",
		"std" => ""),

	array("name" => "Tabbed Sidebar - Custom Tab 6 Title",
		"id" => $shortname . "_sbtab_custom_tab_6_title",
		"parent" => "sbtab-settings",
		"type" => "text",
		"std" => $sidebar_tabs['custom_tab_6']['title']),

	array("name" => "Tabbed Sidebar - Custom Tab 6 Contents",
		"id" => $shortname . "_sbtab_custom_tab_6_contents",
		"parent" => "sbtab-settings",
		"type" => "textarea",
		"std" => ""),

	array("name" => "Tabbed Sidebar - Custom Tab 7 Title",
		"id" => $shortname . "_sbtab_custom_tab_7_title",
		"parent" => "sbtab-settings",
		"type" => "text",
		"std" => $sidebar_tabs['custom_tab_7']['title']),

	array("name" => "Tabbed Sidebar - Custom Tab 7 Contents",
		"id" => $shortname . "_sbtab_custom_tab_7_contents",
		"parent" => "sbtab-settings",
		"type" => "textarea",
		"std" => ""),

	array("name" => "Tabbed Sidebar - Custom Tab 8 Title",
		"id" => $shortname . "_sbtab_custom_tab_8_title",
		"parent" => "sbtab-settings",
		"type" => "text",
		"std" => $sidebar_tabs['custom_tab_8']['title']),

	array("name" => "Tabbed Sidebar - Custom Tab 8 Contents",
		"id" => $shortname . "_sbtab_custom_tab_8_contents",
		"parent" => "sbtab-settings",
		"type" => "textarea",
		"std" => ""),

	array("name" => "Tabbed Sidebar - Custom Tab 9 Title",
		"id" => $shortname . "_sbtab_custom_tab_9_title",
		"parent" => "sbtab-settings",
		"type" => "text",
		"std" => $sidebar_tabs['custom_tab_9']['title']),

	array("name" => "Tabbed Sidebar - Custom Tab 9 Contents",
		"id" => $shortname . "_sbtab_custom_tab_9_contents",
		"parent" => "sbtab-settings",
		"type" => "textarea",
		"std" => ""),

	array("name" => "Tabbed Sidebar - Custom Tab 10 Title",
		"id" => $shortname . "_sbtab_custom_tab_10_title",
		"parent" => "sbtab-settings",
		"type" => "text",
		"std" => $sidebar_tabs['custom_tab_10']['title']),

	array("name" => "Tabbed Sidebar - Custom Tab 10 Contents",
		"id" => $shortname . "_sbtab_custom_tab_10_contents",
		"parent" => "sbtab-settings",
		"type" => "textarea",
		"std" => ""),

	array("name" => "Page Navigation",
		"type" => "sub-section-3",
		"category" => "pagination-settings",
		"parent" => "blog-features"
	),

	array("name" => "Options for paged navigation of posts",
		"desc" => "Suffusion lets you select your own type of page navigation. And if you don't like Suffusion's page navigation styles, you can always use WP-PageNavi.
				If you use WP-PageNavi then the selection here is ignored. ",
		"id" => $shortname . "_pagination_type",
		"parent" => "pagination-settings",
		"type" => "radio",
		"options" => array("old-new" => "Simple navigation, showing links to a page with older posts and a page with newer posts",
			"numbered" => "A numbered listing of pages"),
		"std" => "old-new"),

	array("name" => "Numbered Listing - Page x of y",
		"desc" => "If you have chosen to display a numbered listing of pages, you can choose to show prefix the page list that will highlight which page you are on.
				It will put in a text saying \"Page x of y\". If you use WP-PageNavi then the selection here is ignored.",
		"id" => $shortname . "_pagination_index",
		"parent" => "pagination-settings",
		"type" => "radio",
		"options" => array("show" => "Show \"Page x of y\"",
			"hide" => "Don't show \"Page x of y\""),
		"std" => "show"),

	array("name" => "Numbered Listing - Previous and Next links",
		"desc" => "If you have chosen to display a numbered listing of pages, you can choose to additionally show links for \"Older Entries\" and \"Newer Entries\".
				If you use WP-PageNavi then the selection here is ignored.",
		"id" => $shortname . "_pagination_prev_next",
		"parent" => "pagination-settings",
		"type" => "radio",
		"options" => array("show" => "Show links for \"Older Entries\" and \"Newer Entries\"",
			"hide" => "Don't show links for \"Older Entries\" and \"Newer Entries\""),
		"std" => "show"),

	array("name" => "Numbered Listing - Show all pages in listing",
		"desc" => "If you have chosen to display a numbered listing of pages, you can choose to display all the pages in the list or replace it with dots as appropriate.
				In case of a large number of pages you might prefer to use dots. If you use WP-PageNavi then the selection here is ignored.",
		"id" => $shortname . "_pagination_show_all",
		"parent" => "pagination-settings",
		"type" => "radio",
		"options" => array("all" => "Show all pages in the list",
			"dots" => "Replace pages in the middle with dots"),
		"std" => "dots"),

	array("name" => "Options for paged navigation of comments",
		"desc" => "Here you can decide if you want paged navigation for your comments: ",
		"id" => $shortname . "_cpagination_type",
		"parent" => "pagination-settings",
		"type" => "radio",
		"options" => array("old-new" => "Simple navigation, showing links to a page with older comments and a page with newer comments",
			"numbered" => "A numbered listing of pages for the comments"),
		"std" => "old-new"),

	array("name" => "Numbered Listing of Comments - Page x of y",
		"desc" => "If you have chosen to display a numbered listing of pages for comments, you can choose to show prefix the page list that will highlight which page you are on.
				It will put in a text saying \"Page x of y\".",
		"id" => $shortname . "_cpagination_index",
		"parent" => "pagination-settings",
		"type" => "radio",
		"options" => array("show" => "Show \"Page x of y\"",
			"hide" => "Don't show \"Page x of y\""),
		"std" => "show"),

	array("name" => "Numbered Listing of Comments - Previous and Next links",
		"desc" => "If you have chosen to display a numbered listing of pages for comments, you can choose to additionally show links for \"Older Comments\" and \"Newer Comments\"",
		"id" => $shortname . "_cpagination_prev_next",
		"parent" => "pagination-settings",
		"type" => "radio",
		"options" => array("show" => "Show links for \"Older Comments\" and \"Newer Comments\"",
			"hide" => "Don't show links for \"Older Comments\" and \"Newer Comments\""),
		"std" => "show"),

	array("name" => "Numbered Listing of Comments - Show all comment pages in listing",
		"desc" => "If you have chosen to display a numbered listing of comment pages, you can choose to display all the pages in the list or replace it with dots as appropriate.
				In case of a large number of pages you might prefer to use dots.",
		"id" => $shortname . "_cpagination_show_all",
		"parent" => "pagination-settings",
		"type" => "radio",
		"options" => array("all" => "Show all pages in the list",
			"dots" => "Replace pages in the middle with dots"),
		"std" => "dots"),

	array("name" => "User Profiles",
		"type" => "sub-section-3",
		"category" => "user-profiles",
		"parent" => "blog-features"
	),

	array("name" => "Select Additional Social Networks",
		"desc" => "You can add other contact methods for users on your blog. These will show up in the admin page under Users -&gt; Your Profile.
				This will take effect only if you are at WordPress verison 2.9 or later: ",
		"id" => $shortname . "_uprof_networks",
		"parent" => "user-profiles",
		"type" => "multi-select",
		"options" => suf_get_formatted_options_array($shortname . "_uprof_networks", $social_networks), "std" => ""),

	array("name" => "Show author information for individual posts and pages",
		"desc" => "You can add author information to each post. In subsequent options you can specify what you want to put in the author information section.",
		"id" => $shortname . "_uprof_post_info_enabled",
		"parent" => "user-profiles",
		"type" => "radio",
		"options" => array("hide" => "Don't show author information", "bottom" => "Show information at the bottom of the content for pages and posts",
			'pages' => "Show information for pages only", 'posts' => 'Show information for posts only'
		),
		"std" => "hide"),

	array("name" => "Author information header",
		"desc" => "Specify the header for the author information section. Leave blank if you don't want a header",
		"id" => $shortname . "_uprof_post_info_header",
		"parent" => "user-profiles",
		"type" => "text",
		"std" => "[suffusion-the-author]"),

	array("name" => "Author Gravatar",
		"desc" => "You can choose to show the Gravatar for the author in the information section",
		"id" => $shortname . "_uprof_post_info_gravatar",
		"parent" => "user-profiles",
		"type" => "radio",
		"options" => array("hide" => "Don't show Gravatar", "show" => "Show Gravatar"),
		"std" => "show"),

	array("name" => "Gravatar Size",
		"desc" => "Set the size of the gravatar",
		"id" => $shortname . "_uprof_post_info_gravatar_size",
		"parent" => "user-profiles",
		"type" => "radio",
		"options" => array("32" => "32px", "48" => "48px", "64" => "64px", "96" => "96px", "128" => "128px",),
		"std" => "64"),

	array("name" => "Gravatar Alignment",
		"desc" => "Which side do you want your Gravatar?",
		"id" => $shortname . "_uprof_post_info_gravatar_alignment",
		"parent" => "user-profiles",
		"type" => "radio",
		"options" => array("left" => "Left", "right" => "Right"),
		"std" => "left"),

	array("name" => "Author information content",
		"desc" => "Here you can put in any information you want about the author. You can use any of the author short codes:",
		"id" => $shortname . "_uprof_post_info_content",
		"parent" => "user-profiles",
		"type" => "textarea",
		"std" => "[suffusion-the-author display='description']"),

	array("name" => "Analytics",
		"type" => "sub-section-3",
		"category" => "analytics",
		"parent" => "blog-features"
	),

	array("name" => "Enable Analytics?",
		"desc" => "If you have a Google Analytics acccount you can add your tracking code through this section. " .
				"Note that if you are using a separate plugin for analytics you can ignore this section (i.e., don't enable Analytics).",
		"id" => $shortname . "_analytics_enabled",
		"parent" => "analytics",
		"type" => "radio",
		"note" => "Please set this option to \"Analytics enabled\" if you want to override the theme's settings for Analytics.",
		"options" => array("not-enabled" => "Analytics not enabled(default)",
			"enabled" => "Analytics enabled"),
		"std" => "not-enabled"),

	array("name" => "Custom Google Analytics Tracking Code",
		"desc" => "Enter your tracking code here for Google Analytics (with the <code>&lt;script&gt;</code> and <code>&lt;/script&gt;</code> tags). Note that you can skip this if you are using a plugin for analytics",
		"id" => $shortname . "_custom_analytics_code",
		"parent" => "analytics",
		"type" => "textarea",
		"hint" => "Enter the tracking code here",
		"note" => "If you have any text here, it will be included with your pages (even if incorrect!!). Note that if your analytics are not enabled then this will be ignored.",
		"std" => ""),

	array("name" => "OpenID Setup",
		"type" => "sub-section-3",
		"category" => "openid-setup",
		"parent" => "blog-features"
	),

	array("name" => "Enable OpenID support?",
		"desc" => "If you have set up your blog as an <a href=\"http://openid.net/\">OpenID</a> server, you will need to populate the OpenID server and delegate here." .
				"This theme currently does not help set your blog up as an OpenID provider. It only supports your blog if you have OpenID enabled. If you want to set your blog as a server see <a href=\"http://intertwingly.net/blog/2007/01/03/OpenID-for-non-SuperUsers\">here</a>.",
		"id" => $shortname . "_openid_enabled",
		"parent" => "openid-setup",
		"type" => "radio",
		"note" => "Please set this option to \"OpenID enabled\" if you want to override the theme's settings for OpenID.",
		"options" => array("not-enabled" => "OpenID not enabled(default)",
			"enabled" => "OpenID enabled"),
		"std" => "not-enabled"),

	array("name" => "OpenID Server",
		"desc" => "Set the location of your OpenID server. " .
				"If you have chosen \"OpenID not enabled\" above then this setting will be ignored.",
		"id" => $shortname . "_openid_server",
		"parent" => "openid-setup",
		"type" => "text",
		"hint" => "Enter the full URL here (including http://)",
		"std" => ""),

	array("name" => "OpenID Delegate",
		"desc" => "Set the location of your OpenID delegate. " .
				"If you have chosen \"OpenID not enabled\" above then this setting will be ignored.",
		"id" => $shortname . "_openid_delegate",
		"parent" => "openid-setup",
		"type" => "text",
		"hint" => "Enter the full URL here (including http://)",
		"std" => ""),

	array("name" => "Custom Includes",
		"type" => "sub-section-3",
		"category" => "custom-additions",
		"parent" => "blog-features"
	),

	array("name" => "Don't like the default styles? Add your own...",
		"desc" => "If you are really picky about how your blog should look and the bundled styles don't make you happy, feel free to add your own styles here.
				You can either add externally defined stylesheets or define the CSS here.
				These are called up at the end of all other stylesheet invocations (unless of course you have a plugin that adds something after this!), so what you define here will pretty much override everything else.",
		"parent" => "custom-additions",
		"category" => "custom-css",
		"type" => "sub-section-4",
	),

	array("name" => "Custom Styles",
		"desc" => "If you want to define any custom styles, include the CSS code here. These styles will override all other styles that you have defined / set.
				Don't include the <code>&lt;style&gt;</code> and <code>&lt;/style&gt;</code> tags.",
		"id" => $shortname . "_custom_css_code",
		"parent" => "custom-additions",
		"grouping" => "custom-css",
		"type" => "textarea",
		"hint" => "Enter the CSS styles here",
		"note" => "If you have any text here, it will be included in the header of your pages (even if incorrect!!).",
		"std" => ""),

	array("name" => "First Additional Stylesheet link",
		"desc" => "If you want to define any additional stylesheets, include the entire link here for the first sheet. An example would be a plugin with a separate stylesheet.",
		"id" => $shortname . "_custom_css_link_1",
		"parent" => "custom-additions",
		"grouping" => "custom-css",
		"type" => "text",
		"hint" => "Enter the stylesheet here, including http://",
		"std" => ""),

	array("name" => "Second Additional Stylesheet link",
		"desc" => "If you want to define any additional stylesheets, include the entire link here for the second sheet. An example would be a plugin with a separate stylesheet.",
		"id" => $shortname . "_custom_css_link_2",
		"parent" => "custom-additions",
		"grouping" => "custom-css",
		"type" => "text",
		"hint" => "Enter the stylesheet here, including http://",
		"std" => ""),

	array("name" => "Third Additional Stylesheet link",
		"desc" => "If you want to define any additional stylesheets, include the entire link here for the third sheet. An example would be a plugin with a separate stylesheet.",
		"id" => $shortname . "_custom_css_link_3",
		"parent" => "custom-additions",
		"grouping" => "custom-css",
		"type" => "text",
		"hint" => "Enter the stylesheet here, including http://",
		"std" => ""),

	array("name" => "Custom PHP",
		"desc" => "Suffusion offers a number of action hooks defined in the actions.php file, and some filter hooks defined in the file filters.php.
			You can extend this functionality by including your own PHP.",
		"parent" => "custom-additions",
		"category" => "custom-php",
		"type" => "sub-section-4",
	),

	array("name" => "Custom PHP file location",
		"desc" => "You can define your custom PHP code in a separate file and include a reference to that file here. Do note the following:
			<ul class='margin-20'>
				<li>This file must be put somewhere under your WordPress content directory, " . WP_CONTENT_DIR . ".</li>
				<li>Include the path relative to the content directory, e.g. my-functions/custom-functions.php. Make sure you use the path separator \"/\", not \"\\\".</li>
				<li>If your path includes a sub-directory like \"my-functions\", make sure that the sub-directory exists in your content directory.</li>
				<li>Don't use the Unix folder paths \".\" and \"..\".</li>
				<li><b>Don't put any \"echo\" or \"print\" calls in your file outside a function call.</b> Otherwise you will get an error saying that you attempted to write the headers after they had already been sent.</li>
				<li><b>Make sure that your file has no syntax errors.</b> Otherwise you will see a white page.</li>
			</ul>",
		"id" => $shortname . "_custom_php_file",
		"parent" => "custom-additions",
		"grouping" => "custom-php",
		"type" => "text",
		"hint" => "Enter the path to the file",
		"std" => ""),

	array("name" => "Got JavaScript?",
		"desc" => "Here you can add custom JavaScript. This is a feature that will normally not be used, since you will rely on plugins to automatically add JavaScript.",
		"parent" => "custom-additions",
		"category" => "custom-js",
		"type" => "sub-section-4",
	),

	array("name" => "First External JavaScript file",
		"desc" => "If you want to define any additional JavaScript files, include the entire link here for the first file.
				Note that you have to ensure the JavaScript file's variables and definitions don't conflict with other JS variables and definitions. ",
		"id" => $shortname . "_custom_js_file_1",
		"parent" => "custom-additions",
		"grouping" => "custom-js",
		"type" => "text",
		"hint" => "Enter the JavaScript file path here, including http://",
		"std" => ""),

	array("name" => "Second External JavaScript file",
		"desc" => "If you want to define any additional JavaScript files, include the entire link here for the second file.
				Note that you have to ensure the JavaScript file's variables and definitions don't conflict with other JS variables and definitions. ",
		"id" => $shortname . "_custom_js_file_2",
		"parent" => "custom-additions",
		"grouping" => "custom-js",
		"type" => "text",
		"hint" => "Enter the JavaScript file path here, including http://",
		"std" => ""),

	array("name" => "Third External JavaScript file",
		"desc" => "If you want to define any additional JavaScript files, include the entire link here for the third file.
				Note that you have to ensure the JavaScript file's variables and definitions don't conflict with other JS variables and definitions. ",
		"id" => $shortname . "_custom_js_file_3",
		"parent" => "custom-additions",
		"grouping" => "custom-js",
		"type" => "text",
		"hint" => "Enter the JavaScript file path here, including http://",
		"std" => ""),

	array("name" => "Custom Header JavaScript",
		"desc" => "If you want to add some custom JavaScript to your header you can do so here.
				This could include affiliate code or anything else that you want to add.
				Do not include the <code>&lt;script&gt;</code> and <code>&lt;/script&gt;</code> tags.",
		"id" => $shortname . "_custom_header_js",
		"parent" => "custom-additions",
		"grouping" => "custom-js",
		"type" => "textarea",
		"hint" => "Enter the JavaScript here",
		"note" => "If you have any text here, it will be included in the header of your pages (even if incorrect!!).",
		"std" => ""),

	array("name" => "Custom Footer JavaScript",
		"desc" => "If you want to add some custom JavaScript to your footer you can do so here.
				This could include affiliate code or anything else that you want to add.
				Do not include the <code>&lt;script&gt;</code> and <code>&lt;/script&gt;</code> tags.",
		"id" => $shortname . "_custom_footer_js",
		"grouping" => "custom-js",
		"parent" => "custom-additions",
		"type" => "textarea",
		"hint" => "Enter the JavaScript here",
		"note" => "If you have any text here, it will be included in the footer of your pages (even if incorrect!!).",
		"std" => ""),

	array("name" => "Additional Auto-discovery RSS / Atom feeds",
		"desc" => "You might want to set up additional RSS / Atom feeds for your blog, like a \"Post of the Day\" etc. You can add those feeds here.
				Note that this section is for <b>auto-discovery</b> of feeds only. It will make your feed show up in the address bar of browsers like FireFox.",
		"parent" => "custom-additions",
		"category" => "custom-feed",
		"type" => "sub-section-4",
	),

	array("name" => "Disable default feed?",
		"desc" => "By default Suffusion creates the default RSS feed for the theme. If you would prefer using FeedBurner or another such feed, you might want to disable the default feed:",
		"id" => $shortname . "_custom_default_rss_enabled",
		"parent" => "custom-additions",
		"grouping" => "custom-feed",
		"type" => "radio",
		"options" => array("not-enabled" => "Default feed not enabled",
			"enabled" => "Default feed enabled"),
		"std" => "enabled"),

	array("name" => "Address of First Additional RSS Feed",
		"desc" => "If you want to define any additional RSS Feeds, include the entire link here for the first feed. You could set up a FeedBurner feed here",
		"id" => $shortname . "_custom_rss_feed_1",
		"parent" => "custom-additions",
		"grouping" => "custom-feed",
		"type" => "text",
		"hint" => "Enter the feed URL here, including http://",
		"std" => ""),

	array("name" => "Title of First Additional RSS Feed",
		"desc" => "What should the first feed be called? E.g. Post of the day. This will be ignored if the preceding field is blank.",
		"id" => $shortname . "_custom_rss_title_1",
		"parent" => "custom-additions",
		"grouping" => "custom-feed",
		"type" => "text",
		"hint" => "Enter the feed title here",
		"std" => ""),

	array("name" => "Address of Second Additional RSS Feed",
		"desc" => "If you want to define any additional RSS Feeds, include the entire link here for the second feed.",
		"id" => $shortname . "_custom_rss_feed_2",
		"parent" => "custom-additions",
		"grouping" => "custom-feed",
		"type" => "text",
		"hint" => "Enter the feed URL here, including http://",
		"std" => ""),

	array("name" => "Title of Second Additional RSS Feed",
		"desc" => "What should the second feed be called? E.g. Post of the day. This will be ignored if the preceding field is blank.",
		"id" => $shortname . "_custom_rss_title_2",
		"parent" => "custom-additions",
		"grouping" => "custom-feed",
		"type" => "text",
		"hint" => "Enter the feed title here",
		"std" => ""),

	array("name" => "Address of Third Additional RSS Feed",
		"desc" => "If you want to define any additional RSS Feeds, include the entire link here for the third feed.",
		"id" => $shortname . "_custom_rss_feed_3",
		"parent" => "custom-additions",
		"grouping" => "custom-feed",
		"type" => "text",
		"hint" => "Enter the feed URL here, including http://",
		"std" => ""),

	array("name" => "Title of Third Additional RSS Feed",
		"desc" => "What should the third feed be called? E.g. Post of the day. This will be ignored if the preceding field is blank.",
		"id" => $shortname . "_custom_rss_title_3",
		"parent" => "custom-additions",
		"grouping" => "custom-feed",
		"type" => "text",
		"hint" => "Enter the feed title here",
		"std" => ""),

	array("name" => "Address of First Additional Atom Feed",
		"desc" => "If you want to define any additional Atom Feeds, include the entire link here for the first feed.",
		"id" => $shortname . "_custom_atom_feed_1",
		"parent" => "custom-additions",
		"grouping" => "custom-feed",
		"type" => "text",
		"hint" => "Enter the feed URL here, including http://",
		"std" => ""),

	array("name" => "Title of First Additional Atom Feed",
		"desc" => "What should the first feed be called? E.g. Post of the day. This will be ignored if the preceding field is blank.",
		"id" => $shortname . "_custom_atom_title_1",
		"parent" => "custom-additions",
		"grouping" => "custom-feed",
		"type" => "text",
		"hint" => "Enter the feed title here",
		"std" => ""),

	array("name" => "Address of Second Additional Atom Feed",
		"desc" => "If you want to define any additional Atom Feeds, include the entire link here for the second feed.",
		"id" => $shortname . "_custom_atom_feed_2",
		"parent" => "custom-additions",
		"grouping" => "custom-feed",
		"type" => "text",
		"hint" => "Enter the feed URL here, including http://",
		"std" => ""),

	array("name" => "Title of Second Additional Atom Feed",
		"desc" => "What should the second feed be called? E.g. Post of the day. This will be ignored if the preceding field is blank.",
		"id" => $shortname . "_custom_atom_title_2",
		"parent" => "custom-additions",
		"grouping" => "custom-feed",
		"type" => "text",
		"hint" => "Enter the feed title here",
		"std" => ""),

	array("name" => "Address of Third Additional Atom Feed",
		"desc" => "If you want to define any additional Atom Feeds, include the entire link here for the third feed.",
		"id" => $shortname . "_custom_atom_feed_3",
		"parent" => "custom-additions",
		"grouping" => "custom-feed",
		"type" => "text",
		"hint" => "Enter the feed URL here, including http://",
		"std" => ""),

	array("name" => "Title of Third Additional Atom Feed",
		"desc" => "What should the third feed be called? E.g. Post of the day. This will be ignored if the preceding field is blank.",
		"id" => $shortname . "_custom_atom_title_3",
		"parent" => "custom-additions",
		"grouping" => "custom-feed",
		"type" => "text",
		"hint" => "Enter the feed title here",
		"std" => ""),

	array("name" => "Site Optimization",
		"type" => "sub-section-3",
		"category" => "site-optimization",
		"parent" => "blog-features"
	),

	array("name" => "Use Compression for CSS?",
		"desc" => "You can turn on GZip and Minify compression for your CSS files.
			This will speed up the load times and improve your site's performance on Yahoo YSlow or Google Page Speed.
			However GZIP compression might not work for you if your server is not set up to handle GZip compression.
			Also this might not work well with some caching plugins, in which case turn this off. Mind you, only the theme's CSS files are impacted by this, not CSS from plugins",
		"id" => $shortname . "_css_gzip_enabled",
		"parent" => "site-optimization",
		"type" => "radio",
		"options" => array("gzip-minify" => "Enable GZip compression and minification", "gzip" => "Enable GZip compression only",
			"disabled" => "Disable GZip compression"),
		"std" => "disabled"),

	array("name" => "Use CDN version of JQuery?",
		"desc" => "Instead of WP's JS files, you can use Google CDN's JS files for JQuery. This might speed up load times for your users.",
		"id" => $shortname . "_cdn_jquery_enabled",
		"parent" => "site-optimization",
		"type" => "radio",
		"options" => array("cdn" => "Use CDN",
			"wp" => "Use WordPress"),
		"std" => "wp"),

	array("name" => "Use Compression for WP's JS files?",
		"desc" => "You can turn on GZip compression for the WP JS files used by Suffusion.
			This will speed up the load times and improve your site's performance on Yahoo YSlow or Google Page Speed.
			However GZIP compression might not work for you if your server is not set up to handle GZip compression.
			Also this might not work well with some caching plugins, in which case turn this off.
			Mind you, only the WP JS files used by Suffusion are impacted by this, not JS from plugins, or non-WP JS files included by Suffusion",
		"id" => $shortname . "_js_gzip_enabled",
		"parent" => "site-optimization",
		"type" => "radio",
		"options" => array("gzip" => "Enable GZip compression",
			"disabled" => "Disable GZip compression"),
		"std" => "disabled"),

	array("name" => "Use Compression for your site's main content?",
		"desc" => "You can turn on GZip compression for each page on your site.
			This will speed up the load times and improve your site's performance on Yahoo YSlow or Google Page Speed.
			However GZIP compression might not work for you if your server is not set up to handle GZip compression.
			Also this might not work well with some caching plugins, in which case turn this off.
			Mind you, this will not impact linked files (like stylesheets etc.)",
		"id" => $shortname . "_site_gzip_enabled",
		"parent" => "site-optimization",
		"type" => "radio",
		"options" => array("gzip" => "Enable GZip compression",
			"disabled" => "Disable GZip compression"),
		"std" => "disabled"),

	array("name" => "Include JavaScript in Footer",
		"desc" => "Including the JS in the footer will speed up the load times and improve your site's performance on Yahoo YSlow or Google Page Speed. But there may be some incompatibility with certain plugins, in which case leave the JS in the header.",
		"id" => $shortname . "_js_in_footer",
		"parent" => "site-optimization",
		"type" => "radio",
		"options" => array("header" => "JS in header",
			"footer" => "JS in footer"),
		"std" => "header"),

	array("name" => "Auto-generate CSS file for customization options",
		"desc" => "This will generate a CSS file based on your customization selections and link in that file, instead of printing out all styles on your page.
			This is good from an SEO perspective, but sometimes your server might not be configured to allow this. Note that styles entered through Custom Includes are not written to this file.
			In some cases this functionality doesn't work as expected (e.g. Multi-site installations, where it tends to keep saying that the CSS file is not found).
			If it doesn't work for you set this to not generate the CSS.",
		"id" => $shortname . "_autogen_css",
		"parent" => "site-optimization",
		"type" => "radio",
		"options" => array("autogen" => "Auto-generate the CSS",
			"nogen" => "Don't auto-generate the CSS"),
		"std" => "nogen"),

	array("name" => "Cache dynamic options?",
		"desc" => "The foundation of Suffusion is its set of options. Over time this set has become quite large and heavy and tends to take up a lot of memory.
			By caching the options you can save on the load that each page on your site gets.",
		"id" => $shortname . "_cache_unified",
		"parent" => "site-optimization",
		"type" => "radio",
		"options" => array("cache" => "Cache all options", "nocache" => "Don't cache options"),
		"std" => "cache"),

	array("name" => "Child Themes",
		"type" => "sub-section-3",
		"category" => "child-themes",
		"parent" => "blog-features"
	),

	array("name" => "Inherit styles?",
		"desc" => "Suffusion has a multi-level stylesheet hierarchy that processes style.css first, then skin.css, where 'skin' is the light theme corresponding to your theme selection.
			If your theme selection is a dark theme, it then processes dark-style.css and finally dark-skin.css.
			In case of child themes, however, you might not want to load all the CSS files. Pick what you want for your child theme. Note that this might impact gzip/minification:",
		"id" => $shortname . "_style_inheritance",
		"parent" => "child-themes",
		"type" => "radio",
		"options" => array("everything" => "Inherit all stylesheets corresponding to the theme selection (You will still need the @import for Suffusion's style.css)",
			"nothing" => "Don't inherit any stylesheet (all inclusions will be done using @import tags in your child theme's style.css. Use this if you don't want any pre-defined color scheme)"),
		"std" => "everything"),
);
?>